/*  
 *  - - - - - - - - - 
 *   g a l _ a c c h  
 *  - - - - - - - - - 
 *  
 *  This routine is part of the General Astrodynamics Library  
 *
 *  Description:
 *
 *     Computes the body fixed acceleration due to the harmonic 
 *     gravity field of the central body.
 *  
 *  Status: 
 *  
 *     support routine.  
 *  
 *  Given:  
 *
 *     p               d[3]         Position vector in body fixed frame
 *     gm            *gal_gm_t      Gravity Model
 *     max_n            i           Maximum degree to use 
 *     max_m            i           Maximum order to use
 *  
 *  Returned:  
 *  
 *     abf             d[3]         Body Fixed Acceleration
 *     gal_acch         i           Status
 *                                    0 = Success
 *                                    1 = Maximum degree or order exceeds limits of gravity model
 *  Called:
 *
 *     gal_pdp                      p-vector inner (=scalar=dot) product.
 *     gal_stget                    gets spherical terms C & S of degree n and order m
 *                                  from the given gravity model
 *
 *  References:
 *
 *     Satellite Orbits
 *     Oliver Montenbruck, Eberhard Gill
 *     Springer 2005
 *     Pages 61-68
 *  
 *  This revision:  
 * 
 *     2008 May 18 
 *  
 *  Copyright (C) 2008 Paul C. L. Willmott. See notes at end. 
 *  
 *-----------------------------------------------------------------------  
 */  

#ifndef _GAL_ACCH_H_  
#define _GAL_ACCH_H_ 1  

#include "gal_gm.h"
  
#undef  __BEGIN_DECLS  
#undef  __END_DECLS  
#ifdef  __cplusplus  
#define __BEGIN_DECLS extern "C" {  
#define __END_DECLS }  
#else  
#define __BEGIN_DECLS /* empty */  
#define __END_DECLS   /* empty */  
#endif
  
__BEGIN_DECLS  

int
gal_acch
  (
    double pbf[3],
    gal_gm_t *gm,
    int max_n, 
    int max_m,
    double abf[3] 
  ) ;
 
__END_DECLS  
  
#endif /* !_GAL_ACCH_H_ */ 

/*
 *  gal - General Astrodynamics Library  
 *  Copyright (C) 2008 Paul C. L. Willmott  
 *  
 *  This program is free software; you can redistribute it and/or modify  
 *  it under the terms of the GNU General Public License as published by  
 *  the Free Software Foundation; either version 2 of the License, or  
 *  (at your option) any later version.  
 *  
 *  This program is distributed in the hope that it will be useful,  
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of  
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the  
 *  GNU General Public License for more details.  
 *  
 *  You should have received a copy of the GNU General Public License along  
 *  with this program; if not, write to the Free Software Foundation, Inc.,  
 *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.  
 *    
 *  Contact:  
 *    
 *  Paul Willmott  
 *  vp9mu@amsat.org  
 */  
  
