/*  
 *  - - - - - - - - -
 *   g a l _ c 2 m e  
 *  - - - - - - - - -
 *  
 *  This routine is part of the General Astrodynamics Library  
 *  
 *  Description: 
 *  
 *     This routine transforms a pv-vector from the ICRF
 *     reference frame to the planet mean equator reference frame.
 *
 *  Status:
 *  
 *     support routine.  
 *  
 *  Given:
 *  
 *     icrf          d[2][3]        pv-vector in ICRF inertial frame
 *     alpha            d           Right ascension of planet spin axis ( radians )
 *     delta            d           Declination of planet spin axis ( radians )
 *  
 *  Returned:
 *  
 *     merf          d[2][3]        pv-vector in planet mean equator frame
 *
 *  Called:
 *
 *     gal_rz        Rotate r matrix about z axis
 *     gal_rx        Rotate r matrix about x axis
 *     gal_ir        Form r identity matrix
 *     gal_rxpv      Multiply pv-vector by r-matrix
 *
 *  References:
 *
 *    Mars Pathfinder Project Planetary Constants and Models
 *    Jet Propulsion Laboratory, December 1995
 *    Chapters 2, 4, and 5
 *
 *  This revision:
 *  
 *     2008 December 30  
 *  
 *  Copyright (C) 2008 Paul C. L. Willmott. See notes at end.  
 *  
 *-----------------------------------------------------------------------  
 */  

#ifndef _GAL_C2ME_H_  
#define _GAL_C2ME_H_ 1  

#undef __BEGIN_DECLS  
#undef __END_DECLS  
#ifdef __cplusplus  
#define __BEGIN_DECLS extern "C" {  
#define __END_DECLS }  
#else  
#define __BEGIN_DECLS /* empty */  
#define __END_DECLS   /* empty */  
#endif
  
__BEGIN_DECLS  
  
void  
gal_c2me  
 ( 
   double icrf[2][3],
   double alpha,
   double delta,
   double merf[2][3]
 ) ;  
  
__END_DECLS  
  
#endif /* !_GAL_C2ME_H_ */  

/*  
 *  gal - General Astrodynamics Library  
 *  Copyright (C) 2008 Paul C. L. Willmott  
 *  
 *  This program is free software; you can redistribute it and/or modify  
 *  it under the terms of the GNU General Public License as published by  
 *  the Free Software Foundation; either version 2 of the License, or  
 *  (at your option) any later version.  
 *  
 *  This program is distributed in the hope that it will be useful,  
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of  
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the  
 *  GNU General Public License for more details.  
 *  
 *  You should have received a copy of the GNU General Public License along  
 *  with this program; if not, write to the Free Software Foundation, Inc.,  
 *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.  
 *  
 *  Contact:  
 *  
 *  Paul Willmott  
 *  vp9mu@amsat.org  
 */  
