/*  
 *  - - - - - - - - - - -  
 *   g a l _ c 2 t c e o  
 *  - - - - - - - - - - -  
 *  
 *  This routine is part of the General Astrodynamics Library  
 *  
 *  Description: 
 *  
 *  Assemble the celestial to terrestrial matrix from CIO-based  
 *  components (the celestial-to-intermediate matrix, the Earth Rotation  
 *  Angle and the polar motion matrix).  
 *  
 *  This routine is an independent translation of a FORTRAN routine  
 *  that is part of IAU's SOFA software collection.  
 *  
 *  Status:
 *  
 *     obsolete routine.  
 *  
 *  Given:
 *  
 *     rc2i             d[3][3]     celestial-to-intermediate matrix  
 *     era                 d        Earth rotation angle  
 *     rpom             d[3][3]     polar-motion matrix  
 *  
 *  Returned:
 *  
 *     rc2t             d[3][3]     celestial-to-terrestrial matrix  
 *  
 *  Notes:  
 *  
 *  1) The name of the present routine, gal_c2tceo, reflects the original  
 *     name of the celestial intermediate origin (CIO), which before the  
 *     adoption of IAU 2006 Resolution 2 was called the "celestial  
 *     ephemeris origin" (CEO).  
 *  
 *  2) When the name change from CEO to CIO occurred, a new SOFA routine  
 *     called gal_c2tcio was introduced as the successor to the existing  
 *     gal_c2tceo.  The present routine is merely a front end to the new  
 *     one.  
 *  
 *  3) The present routine is included in the SOFA collection only to  
 *     support existing applications.  It should not be used in new  
 *     applications.  
 *  
 *  Called:
 *  
 *     gal_c2tcio         form CIO-based celestial-to-terrestrial matrix  
 *  
 *  This revision:
 *  
 *     2007 May 9 ( c version 2008 March 15 )  
 *  
 *  
 *  Copyright (C) 2008 Paul C. L. Willmott. See notes at end.  
 *  
 *-----------------------------------------------------------------------  
 */  
  
#ifndef _GAL_C2TCEO_H_  
#define _GAL_C2TCEO_H_ 1  

#include "gal_c2tcio.h"  

#define gal_c2tceo( rc2i, era, rpom, rc2t ) gal_c2tcio( rc2i, ( era ), rpom, rc2t )  
  
#endif /* !_GAL_C2TCEO_H_ */  

/*  
 *  gal - General Astrodynamics Library  
 *  Copyright (C) 2008 Paul C. L. Willmott  
 *  
 *  This program is free software; you can redistribute it and/or modify  
 *  it under the terms of the GNU General Public License as published by  
 *  the Free Software Foundation; either version 2 of the License, or  
 *  (at your option) any later version.  
 *  
 *  This program is distributed in the hope that it will be useful,  
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of  
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the  
 *  GNU General Public License for more details.  
 *  
 *  You should have received a copy of the GNU General Public License along  
 *  with this program; if not, write to the Free Software Foundation, Inc.,  
 *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.  
 *  
 *  Contact:  
 *  
 *  Paul Willmott  
 *  vp9mu@amsat.org  
 */  
