/*  
 *  - - - - - - - - - - -
 *   g a l _ e a a d h p  
 *  - - - - - - - - - - -
 *  
 *  This routine is part of the General Astrodynamics Library  
 *
 *  Description:
 *
 *     Computes the Earth's Atmospheric Density using the
 *     Harris-Priester Density Model
 *  
 *  Status: 
 *  
 *     support routine.  
 *  
 *  Given:  
 *
 *     pv              d[3]         Position vector of satellite ( m, ms^-1 )
 *                                  True-of-date inertial reference frame
 *     height           d           Height of the satellite above mean sea level ( m )
 *     alpha            d           Right ascension of the Sun ( radians )
 *     delta            d           Declination of the Sun ( radians )
 *  
 *  Returned:  
 *  
 *     ad               d           Atmospheric density ( kg m^-3 )
 *     gal_eaadhp       i           0 = success
 *                                  1 = height out of range of model
 *
 *  Called:
 *
 *     gal_pdp          p-vector dot product
 *     gal_pm           modulus of p-vector
 *
 *  References:
 *
 *     Satellite Orbits
 *     Oliver Montenbruck, Eberhard Gill
 *     Springer 2005
 *     Pages 89-91
 *  
 *  This revision:  
 * 
 *     2009 January 4 
 *  
 *  Copyright (C) 2009 Paul C. L. Willmott. See notes at end. 
 *  
 *-----------------------------------------------------------------------  
 */  

#ifndef _GAL_EAADHP_H_  
#define _GAL_EAADHP_H_ 1  

#undef  __BEGIN_DECLS  
#undef  __END_DECLS  
#ifdef  __cplusplus  
#define __BEGIN_DECLS extern "C" {  
#define __END_DECLS }  
#else  
#define __BEGIN_DECLS /* empty */  
#define __END_DECLS   /* empty */  
#endif
  
__BEGIN_DECLS  

int
gal_eaadhp
  (
    double p[3],
    double height,
    double alpha,
    double delta,
    double *ad
  ) ;
 
__END_DECLS  
  
#endif /* !_GAL_EAADHP_H_ */ 

/*
 *  gal - General Astrodynamics Library  
 *  Copyright (C) 2009 Paul C. L. Willmott  
 *  
 *  This program is free software; you can redistribute it and/or modify  
 *  it under the terms of the GNU General Public License as published by  
 *  the Free Software Foundation; either version 2 of the License, or  
 *  (at your option) any later version.  
 *  
 *  This program is distributed in the hope that it will be useful,  
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of  
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the  
 *  GNU General Public License for more details.  
 *  
 *  You should have received a copy of the GNU General Public License along  
 *  with this program; if not, write to the Free Software Foundation, Inc.,  
 *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.  
 *    
 *  Contact:  
 *    
 *  Paul Willmott  
 *  vp9mu@amsat.org  
 */  
  
