/*  
 *  - - - - - - - - - - - - - - - -
 *   g a l _ e l l i s o i d s . h  
 *  - - - - - - - - - - - - - - - -
 *  
 *  This header file is part of the General Astrodynamics Library  
 *
 *  Description:
 *
 *     This header file includes the header files of the routines that make
 *     up the ellipsoids sub-library, and defines the constants for the
 *     Ellipsoid Model identifiers. 
 *  
 *  Status: 
 *  
 *     Sub-library header file  
 *  
 *  Includes:
 *
 *     gal_emdetails.h                Get full details of Ellipsoid Model
 *     gal_emname.h                   Get the name of Ellipsoid Model  
 *     gal_emparams.h                 Get the parameters of Ellipsiod Model
 *  
 *  This revision:  
 *  
 *     2009 January 6 
 *  
 *  Copyright (C) 2008, 2009 Paul C. L. Willmott. See notes at end. 
 *  
 *-----------------------------------------------------------------------  
 */  

#ifndef _GAL_ELLIPSOIDS_H_
#define _GAL_ELLIPSOIDS_H_ 1

#include "gal_emdetails.h"
#include "gal_emname.h"  
#include "gal_emparams.h"

#undef __BEGIN_DECLS
#undef __END_DECLS
#ifdef __cplusplus
#define __BEGIN_DECLS extern "C" {
#define __END_DECLS }
#else
#define __BEGIN_DECLS /* empty */
#define __END_DECLS /* empty */
#endif

__BEGIN_DECLS

/*
 * ---------------------------------------------
 * Constants for the Ellipsoid Model Identifiers
 * ---------------------------------------------
 */
 
enum {
  GAL_EMEA_DEL1800    =  0,  /* Delambre 1800                  */
  GAL_EMEA_AIRY1830   =  1,  /* Airy 1830                      */
  GAL_EMEA_EVER1830   =  2,  /* Everest 1830                   */
  GAL_EMEA_EVER1830BA =  3,  /* Everest 1830 Boni Alt          */
  GAL_EMEA_BESL1841   =  4,  /* Bessel 1841                    */
  GAL_EMEA_CL1866	  =  5,  /* Clarke 1866                    */
  GAL_EMEA_CL1880	  =  6,  /* Clarke 1880                    */
  GAL_EMEA_CLA1880M   =  7,  /* Clarke 1880 Modified           */
  GAL_EMEA_HEL1906    =  8,  /* Helmert 1906                   */
  GAL_EMEA_INTL1909   =  9,  /* International 1909             */
  GAL_EMEA_KRSV       = 10,  /* Krassovsky                     */
  GAL_EMEA_MERC1960   = 11,  /* Mercury 1960                   */
  GAL_EMEA_WGS1960    = 12,  /* World Geodetic System 1960     */
  GAL_EMEA_IAU1964    = 13,  /* IAU 1964                       */
  GAL_EMEA_AUSNAT1965 = 14,  /* Australian National 1965       */
  GAL_EMEA_WGS1966    = 15,  /* World Geodetic System 1966     */
  GAL_EMEA_MERC1968M  = 16,  /* Modified Mercury 1968          */
  GAL_EMEA_SA1969     = 17,  /* South American 1969            */
  GAL_EMEA_GRS1967    = 18,  /* Geodetic Reference System 1967 */
  GAL_EMEA_WGS1972    = 19,  /* World Geodetic System 1972     */
  GAL_EMEA_IAG1975    = 20,  /* IAG 1975                       */
  GAL_EMEA_IAU1976    = 21,  /* IAU 1976                       */
  GAL_EMEA_GRS1980    = 22,  /* Geodetic Reference System 1980 */
  GAL_EMEA_MERIT1983  = 23,  /* MERIT 1983                     */
  GAL_EMEA_WGS1984    = 24,  /* World Geodetic System 1984     */
  GAL_EMEA_IERS1989   = 25,  /* IERS 1989                      */
  GAL_EMEA_IERS2000   = 26,  /* IERS 2000                      */
  GAL_EMME_IAU1991    = 27,  /* IAU/IAG/COSPAR 1991 Mercury    */
  GAL_EMVE_IAU1991    = 28,  /* IAU/IAG/COSPAR 1991 Venus      */
  GAL_EMEA_IAU1991    = 29,  /* IAU/IAG/COSPAR 1991 Earth      */
  GAL_EMMA_IAU1991    = 30,  /* IAU/IAG/COSPAR 1991 Mars       */
  GAL_EMJU_IAU1991    = 31,  /* IAU/IAG/COSPAR 1991 Jupiter    */
  GAL_EMSA_IAU1991    = 32,  /* IAU/IAG/COSPAR 1991 Saturn     */
  GAL_EMUR_IAU1991    = 33,  /* IAU/IAG/COSPAR 1991 Uranus     */
  GAL_EMNE_IAU1991    = 34,  /* IAU/IAG/COSPAR 1991 Neptune    */
  GAL_EMPL_IAU1991    = 35,  /* IAU/IAG/COSPAR 1991 Pluto      */
  GAL_EMSU_IAU1991    = 36,  /* IAU/IAG/COSPAR 1991 Sun        */
} ;

__END_DECLS
 
#endif /* !_GAL_ELLIPSOIDS_H_ */

/*
 *  gal - General Astrodynamics Library  
 *  Copyright (C) 2008, 2009 Paul C. L. Willmott  
 *  
 *  This program is free software; you can redistribute it and/or modify  
 *  it under the terms of the GNU General Public License as published by  
 *  the Free Software Foundation; either version 2 of the License, or  
 *  (at your option) any later version.  
 *  
 *  This program is distributed in the hope that it will be useful,  
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of  
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the  
 *  GNU General Public License for more details.  
 *  
 *  You should have received a copy of the GNU General Public License along  
 *  with this program; if not, write to the Free Software Foundation, Inc.,  
 *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.  
 *    
 *  Contact:  
 *    
 *  Paul Willmott  
 *  vp9mu@amsat.org  
 */  
  
