/*  
 *  - - - - - - - - - - -  
 *   g a l _ e p b 2 j d  
 *  - - - - - - - - - - -  
 *  
 *  This routine is part of the General Astrodynamics Library  
 *  
 *  Description: 
 *  
 *  Besselian Epoch to Julian Date.  
 *  
 *  This routine is an independent translation of a FORTRAN routine  
 *  that is part of IAU's SOFA software collection.  
 *  
 *  Status:
 *  
 *     support routine.  
 *  
 *  Given:
 *  
 *     epb                 d        Besselian Epoch (e.g. 1957.3D0)  
 *  
 *  Returned:
 *  
 *     *djm0               d        MJD zero-point: always 2400000.5  
 *     *djm                d        Modified Julian Date  
 *  
 *  Note:  
 *  
 *  1) The Julian Date is returned in two pieces, in the usual SOFA  
 *     manner, which is designed to preserve time resolution.  The  
 *     Julian Date is available as a single number by adding djm0 and  
 *     djm.  
 *  
 *  References:  
 *  
 *     Lieske,J.H., 1979. Astron.Astrophys.,73,282.  
 *  
 *  This revision:
 *  
 *     2003 January 14 ( c version 2008 January 18 )  
 *  
 *  
 *  Copyright (C) 2008 Paul C. L. Willmott. See notes at end.  
 *  
 *-----------------------------------------------------------------------  
 */  
  
#ifndef _GAL_EPB2JD_H_  
#define _GAL_EPB2JD_H_ 1  

#undef __BEGIN_DECLS  
#undef __END_DECLS  
#ifdef __cplusplus  
#define __BEGIN_DECLS extern "C" {  
#define __END_DECLS }  
#else  
#define __BEGIN_DECLS /* empty */  
#define __END_DECLS   /* empty */  
#endif
  
__BEGIN_DECLS  
  
void  
gal_epb2jd  
 (  
    double epb,  
    double *djm0,  
    double *djm  
 ) ;  
  
__END_DECLS  
  
#endif /* !_GAL_EPB2JD_H_ */  

/*  
 *  gal - General Astrodynamics Library  
 *  Copyright (C) 2008 Paul C. L. Willmott  
 *  
 *  This program is free software; you can redistribute it and/or modify  
 *  it under the terms of the GNU General Public License as published by  
 *  the Free Software Foundation; either version 2 of the License, or  
 *  (at your option) any later version.  
 *  
 *  This program is distributed in the hope that it will be useful,  
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of  
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the  
 *  GNU General Public License for more details.  
 *  
 *  You should have received a copy of the GNU General Public License along  
 *  with this program; if not, write to the Free Software Foundation, Inc.,  
 *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.  
 *  
 *  Contact:  
 *  
 *  Paul Willmott  
 *  vp9mu@amsat.org  
 */  
