/*  
 *  - - - - - - - - - - - - - - - - -
 *   g a l _ f a c e x p _ a l l o c
 *  - - - - - - - - - - - - - - - - -
 *  
 *  This routine is part of the General Astrodynamics Library  
 *
 *  Description:
 *
 *     This routine computes a factorial exponent lookup table
 *     required by the gal_factorial2 routine.
 *  
 *  Status: 
 *  
 *     Math special function.  
 *  
 *  Given:  
 *
 *     max_factorial            i           Maximum factorial required
 *  
 *  Returned:  
 * 
 *     *gal_facexp_alloc    gal_facexp_t    Pointer to lookup table if success
 *                                          NULL if memory allocation fails
 *
 *  References:
 *
 *     Calculation of Factorials
 *     M. L. Charnow and Jesse L. Maury, Jr.
 *     NASA TM X-55733 GSFC X-542-66-460
 *     Steptember 1966
 * 
 *  This revision:  
 * 
 *     2008 May 30 
 *  
 *  Copyright (C) 2008 Paul C. L. Willmott. See notes at end. 
 *  
 *-----------------------------------------------------------------------  
 */  

#ifndef _GAL_FACEXP_ALLOC_H_  
#define _GAL_FACEXP_ALLOC_H_ 1  
 
#include "gal_facexpdef.h"

#undef  __BEGIN_DECLS  
#undef  __END_DECLS  
#ifdef  __cplusplus  
#define __BEGIN_DECLS extern "C" {  
#define __END_DECLS }  
#else  
#define __BEGIN_DECLS /* empty */  
#define __END_DECLS   /* empty */  
#endif
  
__BEGIN_DECLS  

gal_facexp_t *
gal_facexp_alloc
  (
     int max_factorial
   ) ;
 
__END_DECLS  
  
#endif /* !_GAL_FACEXP_ALLOC_H_ */ 

/*
 *  gal - General Astrodynamics Library  
 *  Copyright (C) 2008 Paul C. L. Willmott  
 *  
 *  This program is free software; you can redistribute it and/or modify  
 *  it under the terms of the GNU General Public License as published by  
 *  the Free Software Foundation; either version 2 of the License, or  
 *  (at your option) any later version.  
 *  
 *  This program is distributed in the hope that it will be useful,  
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of  
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the  
 *  GNU General Public License for more details.  
 *  
 *  You should have received a copy of the GNU General Public License along  
 *  with this program; if not, write to the Free Software Foundation, Inc.,  
 *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.  
 *    
 *  Contact:  
 *    
 *  Paul Willmott  
 *  vp9mu@amsat.org  
 */  
  
