/*  
 *  - - - - - - - - - - -  
 *   g a l _ f a o m 0 3  
 *  - - - - - - - - - - -  
 *  
 *  This routine is part of the General Astrodynamics Library  
 *  
 *  Description: 
 *  
 *  Fundamental argument, IERS Conventions (2003):  
 *  mean longitude of the Moon's ascending node.  
 *  
 *  This routine is an independent translation of a FORTRAN routine  
 *  that is part of IAU's SOFA software collection.  
 *  
 *  Status:
 *  
 *     canonical model.  
 *  
 *  Given:
 *  
 *     t                   d        TDB, Julian centuries since J2000 (Note 1)  
 *  
 *  Returned:
 *  
 *     gal_faom03          d        Omega, radians (Note 2)  
 *  
 *  Notes:  
 *  
 *  1) Though t is strictly TDB, it is usually more convenient to use TT,  
 *     which makes no significant difference.  
 *  
 *  2) The expression used is as adopted in IERS Conventions (2003) and  
 *     is from Simon et al. (1994).  
 *  
 *  References:  
 *  
 *     McCarthy, D. D., Petit, G. (eds.), IERS Conventions (2003),  
 *     IERS Technical Note No. 32, BKG (2004)  
 *  
 *     Simon, J.-L., Bretagnon, P., Chapront, J., Chapront-Touze, M.,  
 *     Francou, G., Laskar, J. 1994, Astron.Astrophys. 282, 663-683  
 *  
 *  This revision:
 *  
 *     2007 February 13 ( c version 2008 January 19 )  
 *  
 *  
 *  Copyright (C) 2008 Paul C. L. Willmott. See notes at end.  
 *  
 *-----------------------------------------------------------------------  
 */  
  
#ifndef _GAL_FAOM03_H_  
#define _GAL_FAOM03_H_ 1  

#undef __BEGIN_DECLS  
#undef __END_DECLS  
#ifdef __cplusplus  
#define __BEGIN_DECLS extern "C" {  
#define __END_DECLS }  
#else  
#define __BEGIN_DECLS /* empty */  
#define __END_DECLS   /* empty */  
#endif
  
__BEGIN_DECLS  
  
double  
gal_faom03  
 (  
    double t  
 ) ;  
  
__END_DECLS  
  
#endif /* !_GAL_FAOM03_H_ */  

/*  
 *  gal - General Astrodynamics Library  
 *  Copyright (C) 2008 Paul C. L. Willmott  
 *  
 *  This program is free software; you can redistribute it and/or modify  
 *  it under the terms of the GNU General Public License as published by  
 *  the Free Software Foundation; either version 2 of the License, or  
 *  (at your option) any later version.  
 *  
 *  This program is distributed in the hope that it will be useful,  
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of  
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the  
 *  GNU General Public License for more details.  
 *  
 *  You should have received a copy of the GNU General Public License along  
 *  with this program; if not, write to the Free Software Foundation, Inc.,  
 *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.  
 *  
 *  Contact:  
 *  
 *  Paul Willmott  
 *  vp9mu@amsat.org  
 */  
