/*  
 *  - - - - - - - - - - -  
 *   g a l _ f k 5 h i p  
 *  - - - - - - - - - - -  
 *  
 *  This routine is part of the General Astrodynamics Library  
 *  
 *  Description: 
 *  
 *  FK5 to Hipparcos rotation and spin.  
 *  
 *  This routine is an independent translation of a FORTRAN routine  
 *  that is part of IAU's SOFA software collection.  
 *  
 *  Status:
 *  
 *     support routine.  
 *  
 *  Returned:
 *  
 *     r5h              d[3][3]     r-matrix: FK5 rotation wrt Hipparcos (Note 2)  
 *     s5h                d[3]      r-vector: FK5 spin wrt Hipparcos (Note 3)  
 *  
 *  Notes:  
 *  
 *  1) This routine models the FK5 to Hipparcos transformation as a  
 *     pure rotation and spin;  zonal errors in the FK5 catalogue are  
 *     not taken into account.  
 *  
 *  2) The r-matrix r5h operates in the sense:  
 *  
 *           P_Hipparcos = r5h x P_FK5  
 *  
 *     where P_FK5 is a p-vector in the FK5 frame, and P_Hipparcos is  
 *     the equivalent Hipparcos p-vector.  
 *  
 *  3) The r-vector s5h represents the time derivative of the FK5 to  
 *     Hipparcos rotation.  The units are radians per year (Julian,  
 *     TDB).  
 *  
 *  Called:
 *  
 *     gal_rv2m           r-vector to r-matrix  
 *  
 *  References:  
 *  
 *     F.Mignard & M.Froeschle, Astron. Astrophys. 354, 732-739 (2000).  
 *  
 *  This revision:
 *  
 *     2006 November 13 ( c version 2008 June 8 )  
 *  
 *  
 *  Copyright (C) 2008 Paul C. L. Willmott. See notes at end.  
 *  
 *-----------------------------------------------------------------------  
 */  
  
#ifndef _GAL_FK5HIP_H_  
#define _GAL_FK5HIP_H_ 1  

#undef __BEGIN_DECLS  
#undef __END_DECLS  
#ifdef __cplusplus  
#define __BEGIN_DECLS extern "C" {  
#define __END_DECLS }  
#else  
#define __BEGIN_DECLS /* empty */  
#define __END_DECLS   /* empty */  
#endif
  
__BEGIN_DECLS  
  
void  
gal_fk5hip  
 (  
    double r5h[3][3],  
    double s5h[3]  
 ) ;  
  
__END_DECLS  
  
#endif /* !_GAL_FK5HIP_H_ */  

/*  
 *  gal - General Astrodynamics Library  
 *  Copyright (C) 2008 Paul C. L. Willmott  
 *  
 *  This program is free software; you can redistribute it and/or modify  
 *  it under the terms of the GNU General Public License as published by  
 *  the Free Software Foundation; either version 2 of the License, or  
 *  (at your option) any later version.  
 *  
 *  This program is distributed in the hope that it will be useful,  
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of  
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the  
 *  GNU General Public License for more details.  
 *  
 *  You should have received a copy of the GNU General Public License along  
 *  with this program; if not, write to the Free Software Foundation, Inc.,  
 *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.  
 *  
 *  Contact:  
 *  
 *  Paul Willmott  
 *  vp9mu@amsat.org  
 */  
