/*  
 *  - - - - - - - - - - - - -
 *   g a l _ g m d e n o r m
 *  - - - - - - - - - - - - -
 *  
 *  This routine is part of the General Astrodynamics Library  
 *
 *  Description:
 *
 *     This routine un-normalizes a gravity model's coefficients
 *  
 *  Status: 
 *  
 *     support routine.  
 *  
 *  Given:  
 *
 *     *gm1            gal_gm_t       Source gravity model
 *  
 *  Returned:  
 *  
 *     *gm2            gal_gm_t       Target gravity model
 *     *gal_gmdenorm   gal_gm_t       *gm2
 *  
 *  Called:  
 *  
 *     gal_stunf                      Compute spherical terms un-normalization factor
 *     gal_stget                      Get spherical terms from gracity model
 *     gal_stset                      Set spherical terms in gravity model
 *     gal_facexp_alloc               Allocate factorial exponent lookup table
 *     gal_facexp_free                Deallocate factorial exponent lookup table
 *  
 *  This revision:  
 * 
 *     2008 May 30 
 *  
 *  Copyright (C) 2008 Paul C. L. Willmott. See notes at end. 
 *  
 *-----------------------------------------------------------------------  
 */  

#ifndef _GAL_GMDENORM_H_  
#define _GAL_GMDENORM_H_ 1  

#include "gal_gm.h"
  
#undef  __BEGIN_DECLS  
#undef  __END_DECLS  
#ifdef  __cplusplus  
#define __BEGIN_DECLS extern "C" {  
#define __END_DECLS }  
#else  
#define __BEGIN_DECLS /* empty */  
#define __END_DECLS   /* empty */  
#endif
  
__BEGIN_DECLS  

gal_gm_t *
gal_gmdenorm
  (
    gal_gm_t *gm1,
    gal_gm_t *gm2
  ) ;
 
__END_DECLS  
  
#endif /* !_GAL_GMDENORM_H_ */ 

/*
 *  gal - General Astrodynamics Library  
 *  Copyright (C) 2008 Paul C. L. Willmott  
 *  
 *  This program is free software; you can redistribute it and/or modify  
 *  it under the terms of the GNU General Public License as published by  
 *  the Free Software Foundation; either version 2 of the License, or  
 *  (at your option) any later version.  
 *  
 *  This program is distributed in the hope that it will be useful,  
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of  
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the  
 *  GNU General Public License for more details.  
 *  
 *  You should have received a copy of the GNU General Public License along  
 *  with this program; if not, write to the Free Software Foundation, Inc.,  
 *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.  
 *    
 *  Contact:  
 *    
 *  Paul Willmott  
 *  vp9mu@amsat.org  
 */  
  
