/*  
 *  - - - - - - - - - -
 *   g a l _ g m u z h
 *  - - - - - - - - - -
 *  
 *  This routine is part of the General Astrodynamics Library  
 *
 *  Description:
 *
 *     This routine calculates an un-normalized zonal harmonic
 *  
 *  Status: 
 *  
 *     support routine.  
 *  
 *  Given:  
 *
 *     *gm             gal_gm_t       Gravity model
 *     *facexp       gal_facexp_t     Pointer to factorial exponent lookup table
 *     harmonic           i           Required harmonic
 *  
 *  Returned:  
 *  
 *     gal_gmuzh          d           Unnormalized zonal harmonic
 *  
 *  Called:  
 *  
 *     gal_stunf                      Compute spherical terms un-normalization factor
 *     gal_stget                      Get spherical terms from gracity model
 *  
 *  This revision:  
 * 
 *     2008 May 30
 *  
 *  Copyright (C) 2008 Paul C. L. Willmott. See notes at end. 
 *  
 *-----------------------------------------------------------------------  
 */  

#ifndef _GAL_GMUZH_H_  
#define _GAL_GMUZH_H_ 1  

#include "gal_gm.h"
#include "gal_facexpdef.h"
  
#undef  __BEGIN_DECLS  
#undef  __END_DECLS  
#ifdef  __cplusplus  
#define __BEGIN_DECLS extern "C" {  
#define __END_DECLS }  
#else  
#define __BEGIN_DECLS /* empty */  
#define __END_DECLS   /* empty */  
#endif
  
__BEGIN_DECLS  

double
gal_gmuzh
  (
    gal_gm_t *gm,
    gal_facexp_t *facexp,
    int harmonic
  ) ;
 
__END_DECLS  
  
#endif /* !_GAL_GMUZH_H_ */ 

/*
 *  gal - General Astrodynamics Library  
 *  Copyright (C) 2008 Paul C. L. Willmott  
 *  
 *  This program is free software; you can redistribute it and/or modify  
 *  it under the terms of the GNU General Public License as published by  
 *  the Free Software Foundation; either version 2 of the License, or  
 *  (at your option) any later version.  
 *  
 *  This program is distributed in the hope that it will be useful,  
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of  
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the  
 *  GNU General Public License for more details.  
 *  
 *  You should have received a copy of the GNU General Public License along  
 *  with this program; if not, write to the Free Software Foundation, Inc.,  
 *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.  
 *    
 *  Contact:  
 *    
 *  Paul Willmott  
 *  vp9mu@amsat.org  
 */  
  
