/*  
 *  - - - - - - - - - - - - - - 
 *   g a l _ g m w g s 6 6 . h  
 *  - - - - - - - - - - - - - - 
 *  
 *  This file is part of the General Astrodynamics Library  
 *
 *  Description:
 *
 *     This file defines the external variables for the WGS66 gravity model.
 *  
 *  Status: 
 *  
 *     Support file gravity model sub-system  
 *
 *  Defines:  
 *
 *     gal_gmwgs66    gal_gm_t      WGS66 gravity model structure
 *
 *  Notes:
 *
 *  1) The value for GM is unknown, so the value for WGS72 is used instead.
 *
 *  This revision:  
 * 
 *     2008 September 20 
 *  
 *  Copyright (C) 2008 Paul C. L. Willmott. See notes at end. 
 *  
 *-----------------------------------------------------------------------  
 */  

#ifndef _GAL_GMWGS66_H_  
#define _GAL_GMWGS66_H_ 1  

#include "gal_gm.h"
#include "gal_const.h"
  
#undef  __BEGIN_DECLS  
#undef  __END_DECLS  
#ifdef  __cplusplus  
#define __BEGIN_DECLS extern "C" {  
#define __END_DECLS }  
#else  
#define __BEGIN_DECLS /* empty */  
#define __END_DECLS   /* empty */  
#endif
  
__BEGIN_DECLS  

double gal_gmwgs66_terms[25][25] = {
{
                    0e+00,                     0e+00,               1.66300e-08,               2.57100e-07,              -4.54100e-07, 
             -4.01900e-08,               3.35300e-09,               3.06100e-08,              -6.36000e-08,              -5.12200e-08, 
             -1.13500e-08,              -1.03800e-07,              -7.09300e-08,               1.97700e-08,               2.39100e-08, 
              3.51000e-09,              -1.09700e-08,              -2.14500e-08,              -2.79700e-08,              -9.88900e-09, 
             -1.71300e-08,              -2.87900e-09,               2.09600e-08,               1.77000e-08,               2.15600e-08, 

},
{
                    0e+00,                     0e+00,              -1.46700e-06,              -5.76000e-07,               6.34500e-07, 
             -2.13700e-07,              -3.95100e-07,               4.89200e-08,              -3.76400e-09,               2.88300e-09, 
             -1.36000e-07,              -2.01600e-08,               8.86000e-08,               1.84500e-08,              -2.03700e-08, 
             -2.72100e-08,               4.74300e-08,               4.37300e-08,               4.13600e-09,              -2.02700e-08, 
              3.21800e-08,               1.55300e-08,              -1.17000e-08,              -2.18900e-08,              -3.53600e-10, 

},
{
             -4.84205e-04,              -7.13800e-08,               2.50600e-06,               1.48700e-06,              -2.34700e-07, 
             -1.40300e-07,               1.66600e-07,               1.99500e-08,               3.37100e-08,               2.16700e-08, 
             -1.35100e-07,              -3.57100e-08,               1.13000e-07,               6.34900e-08,              -2.83500e-08, 
              2.40200e-08,               2.27000e-08,              -2.14400e-08,              -4.06300e-08,               1.51600e-09, 
              4.56200e-10,              -4.05600e-09,              -2.17200e-08,              -2.24300e-08,              -1.75300e-08, 

},
{
              9.94100e-07,               1.85400e-06,               8.57500e-07,               6.14300e-07,               2.17200e-07, 
              7.22600e-09,              -4.81600e-07,               1.28900e-07,              -9.93200e-08,              -2.18400e-08, 
             -1.16300e-08,              -1.36600e-09,              -2.89600e-09,              -4.16800e-08,              -3.61200e-08, 
              3.95300e-08,               3.84400e-08,               3.39400e-09,              -1.27800e-08,              -2.07300e-08, 
             -2.28900e-08,              -2.02600e-08,              -4.64200e-09,               6.86300e-09,               1.86900e-08, 

},
{
              7.83200e-07,              -6.17300e-07,               3.00800e-07,               9.00900e-07,              -3.42600e-08, 
             -4.75400e-07,              -5.15500e-07,              -9.75900e-08,               4.69000e-08,               1.05800e-07, 
              5.31600e-09,              -2.66400e-08,              -2.98000e-09,               4.26400e-08,              -1.11600e-08, 
             -3.90100e-08,              -1.78300e-08,               3.19600e-10,               1.07400e-08,               1.39300e-08, 
             -1.29700e-08,              -4.45900e-09,               1.45900e-08,               2.33900e-08,               2.44100e-08, 

},
{
              7.99200e-08,              -8.28900e-08,               6.73700e-07,              -3.64600e-07,               7.09800e-08, 
              1.45600e-07,              -1.95500e-07,               1.57900e-07,               1.77000e-07,               7.46500e-08, 
             -2.71500e-08,               1.59700e-08,              -9.82300e-09,               8.26500e-09,              -9.02300e-09, 
             -5.17800e-08,              -2.81400e-08,              -1.25600e-08,              -3.88800e-09,               1.00200e-08, 
              7.86800e-09,              -2.37600e-08,              -1.12900e-09,               1.15100e-08,               3.03300e-09, 

},
{
             -1.83100e-07,              -1.23000e-07,               4.79600e-08,               9.32400e-08,              -4.81500e-08, 
             -1.60900e-07,              -1.90900e-08,               4.03100e-08,               1.79900e-08,               1.32600e-08, 
             -8.29400e-11,              -4.92000e-08,               1.56400e-08,               2.16500e-08,               3.22400e-09, 
              4.91900e-08,              -5.27100e-09,              -9.17500e-09,               1.75200e-08,               2.94000e-09, 
             -5.96400e-09,               1.97000e-08,               1.68000e-08,               3.30600e-09,               7.63200e-09, 

},
{
              1.19100e-07,               1.69600e-08,               1.91200e-07,               5.54500e-08,              -2.37700e-07, 
             -5.31300e-08,              -1.72300e-07,               3.60700e-08,              -3.40200e-08,               4.98400e-08, 
             -5.22800e-08,              -2.86700e-08,              -2.11500e-08,              -1.85700e-09,              -2.55300e-08, 
             -3.01200e-08,              -2.35300e-08,               1.67200e-08,               1.30800e-09,              -2.15100e-08, 
              9.66100e-10,               1.82100e-08,               1.32400e-08,              -4.21400e-09,              -1.09900e-08, 

},
{
             -1.29200e-07,               5.26400e-08,               1.88600e-07,               4.75500e-08,               7.94500e-09, 
             -1.12900e-07,               5.89700e-09,               1.32400e-08,              -1.21200e-07,               8.76500e-09, 
             -1.78900e-08,               6.86300e-08,               5.71800e-08,               5.15800e-08,               7.21200e-08, 
              5.41800e-08,              -4.50000e-08,              -1.67200e-08,               1.05300e-08,              -7.02400e-09, 
              4.81700e-09,               3.19000e-08,               1.31500e-08,              -8.29600e-09,               1.08300e-08, 

},
{
              5.59000e-08,               6.93900e-08,              -7.85000e-10,              -6.07000e-08,              -9.03800e-09, 
             -1.16800e-07,               8.71500e-09,               3.34900e-08,               1.67300e-07,               7.00000e-08, 
              9.46100e-09,              -5.95200e-08,               7.01000e-09,              -3.14700e-08,               2.45200e-08, 
              2.21600e-08,              -1.59900e-08,              -8.75700e-09,               3.00800e-09,              -2.41000e-09, 
              1.72400e-09,               1.04100e-08,               8.72000e-09,               1.77300e-08,               9.79300e-09, 

},
{
             -7.09100e-08,               1.24200e-07,              -4.10600e-08,              -1.05700e-07,              -1.71200e-08, 
              8.44400e-09,              -5.96100e-08,              -1.55000e-08,               8.97700e-08,               1.03400e-07, 
              6.71900e-08,               9.30600e-08,               2.53500e-08,               9.80700e-09,               3.40400e-09, 
              4.64000e-10,              -2.14900e-08,               3.87200e-09,               2.35900e-08,               2.85800e-10, 
             -1.45300e-08,              -2.59500e-08,              -5.39100e-09,               1.91800e-08,               1.42900e-08, 

},
{
             -6.67500e-08,              -1.01600e-08,               5.46500e-08,               7.51300e-08,              -4.13500e-09, 
              1.26000e-08,               6.16600e-08,              -5.77200e-08,               6.68400e-08,               3.14800e-09, 
             -1.28800e-08,               1.15100e-07,               4.81200e-08,               6.57800e-08,              -1.85900e-08, 
              3.40400e-08,              -1.49300e-08,              -2.03200e-08,              -2.46700e-08,              -4.14400e-09, 
              1.36600e-09,               5.38900e-09,               4.29800e-09,              -4.19300e-09,              -7.27300e-09, 

},
{
             -5.76200e-08,               2.55700e-09,               8.61900e-08,               3.12800e-08,               1.85100e-09, 
              5.67900e-08,               3.29100e-08,              -6.33900e-08,              -2.66200e-10,               2.17500e-08, 
             -1.96900e-08,              -1.61900e-08,              -6.47900e-08,               2.08500e-09,               3.51700e-08, 
              5.11100e-08,              -1.90900e-08,              -1.17000e-09,              -2.18200e-08,              -1.14600e-08, 
              7.38800e-09,               2.54600e-08,               1.90800e-08,              -7.43300e-09,              -2.04400e-09, 

},
{
              4.11900e-08,              -5.43900e-08,              -2.31400e-08,               2.32600e-09,              -8.09600e-09, 
              3.14100e-08,              -5.16000e-08,               1.06200e-08,              -6.27300e-08,               3.32500e-08, 
              4.25400e-08,              -8.56500e-09,              -1.18300e-08,              -5.18100e-08,               1.99200e-09, 
             -1.96000e-08,              -1.45700e-08,               2.45000e-08,              -1.25600e-08,              -7.24700e-09, 
             -2.63800e-09,               1.61500e-08,               1.92900e-08,              -3.83300e-09,               3.61500e-09, 

},
{
             -2.23300e-09,               2.26400e-09,               8.45100e-09,               5.08200e-08,               1.51300e-08, 
              3.81500e-08,              -1.07500e-08,               1.92300e-08,              -1.79700e-08,               2.00000e-08, 
              2.77800e-08,               3.31900e-08,               3.49600e-08,              -9.95600e-09,              -5.08700e-08, 
             -1.58200e-09,               7.08400e-09,               1.96100e-08,              -1.38200e-08,              -1.30600e-08, 
              1.67600e-09,               5.19100e-09,              -2.11700e-08,               1.09300e-09,               3.81100e-09, 

},
{
             -1.82900e-08,               4.29800e-08,              -1.75600e-08,               8.29400e-09,               2.87800e-08, 
              4.13000e-08,               4.90300e-08,               3.96700e-08,              -5.41600e-08,              -6.47700e-09, 
             -1.79300e-08,              -2.63600e-08,              -5.23000e-08,               2.38300e-09,               1.27600e-08, 
             -1.27800e-09,               2.44000e-08,              -5.53700e-09,               1.15600e-08,               9.32600e-09, 
             -6.94200e-09,              -2.54600e-08,              -2.47700e-09,               1.20200e-08,              -7.30000e-09, 

},
{
             -2.89800e-08,              -1.17300e-09,               1.13100e-08,              -6.34200e-09,               4.84700e-08, 
             -3.04600e-08,              -1.19300e-08,               4.66000e-08,              -2.62600e-08,              -1.61100e-08, 
             -1.97700e-08,              -1.58300e-09,              -7.70900e-09,              -1.03200e-08,              -3.05200e-08, 
             -3.12500e-08,              -2.03400e-08,              -2.04600e-08,               1.69900e-09,              -1.04200e-08, 
             -7.21500e-09,               6.93000e-09,              -5.09000e-09,              -6.23200e-09,              -9.42000e-09, 

},
{
              3.82200e-08,              -3.02700e-08,               8.01500e-09,               3.70300e-09,               2.70600e-08, 
             -3.75900e-09,              -3.41000e-08,               2.71600e-08,               1.90700e-08,               7.42900e-09, 
              3.43000e-09,               5.18200e-09,               9.08000e-09,               3.07500e-08,              -1.85300e-09, 
              7.98600e-09,              -1.89100e-08,              -5.36100e-08,              -4.75500e-09,               5.10200e-09, 
             -2.32800e-09,               2.28900e-09,              -1.96500e-08,              -1.25500e-08,               5.73300e-10, 

},
{
             -1.17000e-08,              -1.54300e-08,               3.70900e-09,               6.01000e-11,               3.09400e-08, 
              2.65900e-08,              -7.31200e-09,               1.89800e-09,               1.88500e-08,              -2.10600e-08, 
             -1.09700e-08,              -2.92300e-09,               8.03600e-09,               1.63200e-08,              -7.70600e-09, 
             -3.23400e-08,               2.00200e-08,              -9.52800e-09,              -1.37800e-08,              -2.47100e-09, 
              1.38100e-08,               4.55000e-09,               3.42200e-09,              -2.65100e-09,              -2.48200e-09, 

},
{
             -2.35100e-08,              -2.28000e-09,               1.11700e-08,              -3.13900e-08,               7.82900e-10, 
             -7.55900e-09,              -1.38600e-08,              -1.83100e-08,               2.28100e-08,               8.69500e-09, 
             -1.68100e-09,               2.03300e-08,              -1.57200e-09,               1.88600e-09,               1.63300e-09, 
             -1.60500e-08,               4.27100e-09,               3.77800e-08,               1.86100e-08,              -6.00400e-09, 
             -3.99400e-09,               5.09600e-09,               5.27600e-09,              -7.00400e-09,              -2.56500e-10, 

},
{
             -2.20700e-08,              -1.34100e-08,              -4.26200e-09,              -2.13100e-08,              -1.79700e-08, 
             -1.39000e-08,              -8.71900e-09,              -1.68000e-08,               2.31500e-08,               2.66800e-08, 
             -1.55100e-08,               2.47900e-08,              -2.83500e-09,               1.38400e-08,               2.46800e-09, 
             -1.84600e-08,              -1.09400e-08,              -8.63000e-09,              -9.24300e-10,               2.96100e-08, 
             -3.09600e-09,               8.17200e-10,               4.87700e-09,               1.01800e-08,               8.77800e-09, 

},
{
              1.24800e-08,              -6.23200e-09,               5.36800e-09,              -4.11400e-09,              -2.94600e-08, 
             -3.58300e-10,               2.66500e-09,               6.44900e-09,               2.98000e-09,               1.98300e-09, 
              1.19700e-09,               7.36200e-09,               1.22600e-09,               7.80600e-09,               2.20300e-09, 
              3.52600e-09,              -8.48500e-09,               5.74500e-09,               1.98200e-08,              -1.10100e-08, 
             -2.46800e-08,              -7.00700e-09,              -6.70200e-09,               1.52000e-08,              -4.21900e-09, 

},
{
             -8.67000e-09,               7.67100e-09,               3.37700e-09,               6.26900e-09,              -5.42600e-09, 
              6.68700e-09,               3.89800e-09,               1.44100e-08,              -1.90700e-08,              -4.83900e-09, 
              1.82100e-08,              -1.15100e-09,               5.84600e-09,              -5.98200e-09,               5.12500e-09, 
              7.86700e-09,               7.90600e-09,               1.69600e-08,               1.22200e-09,              -1.12400e-08, 
             -1.72800e-08,               4.34100e-09,              -1.95800e-08,              -1.49000e-08,              -2.29200e-09, 

},
{
              1.47100e-09,               1.11000e-08,              -1.80300e-08,               5.19400e-09,              -3.73400e-09, 
             -3.74600e-09,              -1.78200e-09,               9.49800e-10,               2.48000e-10,               5.44000e-09, 
              1.82300e-08,               8.90500e-09,               1.85400e-08,              -2.64000e-09,              -5.08500e-09, 
              1.27200e-08,               1.81200e-08,               4.58100e-09,              -4.28200e-09,              -4.97000e-09, 
              1.01400e-08,               1.29300e-08,              -1.48100e-08,              -8.07300e-09,              -1.16200e-08, 

},
{
             -1.69200e-08,               9.16300e-09,              -4.92100e-09,              -2.71700e-08,              -1.22700e-08, 
             -2.65000e-08,               7.67000e-09,               4.41000e-10,               1.00100e-08,              -1.08900e-08, 
              9.22700e-09,               7.05800e-09,               1.88100e-08,              -1.20800e-08,              -2.06800e-08, 
              8.08300e-09,               6.13900e-09,              -9.60000e-09,               2.77200e-09,              -1.90700e-08, 
             -4.24500e-09,              -6.83700e-09,              -5.83500e-09,               6.00300e-09,              -1.27400e-09, 

},
} ;

gal_gm_t gal_gmwgs66 = {
GAL_SSB_EA,
"WGS-66",
3.986008e+14,
6.378145e+06,
24,
24,
1,
(double *) &gal_gmwgs66_terms
} ;

__END_DECLS  
  
#endif /* !_GAL_GMWGS66_H_ */ 

/*
 *  gal - General Astrodynamics Library  
 *  Copyright (C) 2008 Paul C. L. Willmott  
 *  
 *  This program is free software; you can redistribute it and/or modify  
 *  it under the terms of the GNU General Public License as published by  
 *  the Free Software Foundation; either version 2 of the License, or  
 *  (at your option) any later version.  
 *  
 *  This program is distributed in the hope that it will be useful,  
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of  
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the  
 *  GNU General Public License for more details.  
 *  
 *  You should have received a copy of the GNU General Public License along  
 *  with this program; if not, write to the Free Software Foundation, Inc.,  
 *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.  
 *    
 *  Contact:  
 *    
 *  Paul Willmott  
 *  vp9mu@amsat.org  
 */  
  
