/*  
 *  - - - - - - - - - - - - - - 
 *   g a l _ g m w g s 7 2 . h  
 *  - - - - - - - - - - - - - - 
 *  
 *  This file is part of the General Astrodynamics Library  
 *
 *  Description:
 *
 *     This file defines the external variables for the WGS72 gravity model.
 *  
 *  Status: 
 *  
 *     Support file gravity model sub-system  
 *
 *  Defines:  
 *
 *     gal_gmwgs72    gal_gm_t      WGS72 gravity model structure
 *
 *  This revision:  
 * 
 *     2008 September 20 
 *  
 *  Copyright (C) 2008 Paul C. L. Willmott. See notes at end. 
 *  
 *-----------------------------------------------------------------------  
 */  

#ifndef _GAL_GMWGS72_H_  
#define _GAL_GMWGS72_H_ 1  

#include "gal_gm.h"
#include "gal_const.h"
  
#undef  __BEGIN_DECLS  
#undef  __END_DECLS  
#ifdef  __cplusplus  
#define __BEGIN_DECLS extern "C" {  
#define __END_DECLS }  
#else  
#define __BEGIN_DECLS /* empty */  
#define __END_DECLS   /* empty */  
#endif
  
__BEGIN_DECLS  

double gal_gmwgs72_terms[29][29] = {
{
                    0e+00,                     0e+00,                     0e+00,              2.670300e-07,             -4.805200e-07, 
            -1.279900e-07,              2.981100e-08,              1.442300e-07,              5.701800e-08,             -5.392500e-08, 
            -1.341800e-07,              4.100200e-08,             -2.000800e-08,             -5.419300e-08,             -1.035300e-08, 
             3.839800e-08,              4.751700e-08,              1.527600e-08,             -4.095100e-08,              1.227000e-08, 
                    0e+00,                     0e+00,                     0e+00,                     0e+00,                     0e+00, 
                    0e+00,                     0e+00,                     0e+00,                     0e+00, 
},
{
                    0e+00,                     0e+00,             -1.403600e-06,             -6.457100e-07,              6.512300e-07, 
            -3.177500e-07,             -3.515500e-07,              1.105900e-07,              4.704300e-08,             -3.654600e-08, 
             4.620400e-09,             -9.758500e-08,             -4.925200e-08,             -5.599900e-08,              6.926000e-08, 
            -6.970600e-08,             -7.549700e-08,              1.075200e-07,              1.353000e-07,             -5.251000e-08, 
                    0e+00,                     0e+00,                     0e+00,                     0e+00,                     0e+00, 
                    0e+00,                     0e+00,                     0e+00,                     0e+00, 
},
{
            -4.841605e-04,                     0e+00,              2.442300e-06,              1.406400e-06,             -1.983600e-07, 
            -2.115200e-07,              3.739300e-09,             -2.100900e-07,             -7.558200e-08,             -6.746600e-08, 
            -1.377800e-07,             -1.263500e-07,              3.404800e-09,              7.279300e-08,              3.972500e-08, 
             6.500000e-08,             -2.441500e-08,             -4.212500e-09,              5.324200e-09,             -1.002100e-08, 
                    0e+00,                     0e+00,                     0e+00,                     0e+00,                     0e+00, 
                    0e+00,                     0e+00,                     0e+00,                     0e+00, 
},
{
             9.595800e-07,              2.053600e-06,              9.133200e-07,              7.051200e-07,              3.171300e-07, 
             5.949600e-08,             -4.679600e-07,             -1.226800e-07,              5.599200e-08,              1.257800e-08, 
            -4.505800e-08,             -6.602200e-08,             -2.337900e-08,             -2.573900e-09,             -3.574900e-08, 
             5.388900e-09,              8.520200e-08,              2.867000e-08,             -8.701600e-08,             -5.101800e-09, 
                    0e+00,                     0e+00,                     0e+00,                     0e+00,                     0e+00, 
                    0e+00,                     0e+00,                     0e+00,                     0e+00, 
},
{
             5.519900e-07,             -5.313600e-07,              3.438800e-07,              9.821100e-07,             -1.923500e-07, 
            -6.592000e-07,             -5.521000e-07,              3.332700e-08,              7.914700e-08,             -5.555200e-08, 
            -4.560700e-08,              4.140500e-08,             -1.111600e-08,              5.562400e-08,             -3.020700e-08, 
            -3.324900e-08,             -1.100100e-08,              5.494600e-08,              9.262300e-09,             -5.541100e-08, 
                    0e+00,                     0e+00,                     0e+00,                     0e+00,                     0e+00, 
                    0e+00,                     0e+00,                     0e+00,                     0e+00, 
},
{
             6.587500e-08,             -1.036900e-07,              6.519700e-07,             -4.461900e-07,             -2.799100e-07, 
             1.927200e-07,             -2.441800e-07,              1.581800e-07,              3.076400e-07,              2.237800e-07, 
            -8.322900e-08,              4.795500e-08,              3.805400e-08,             -1.787400e-08,              1.236700e-08, 
            -8.664800e-09,             -6.863300e-09,             -7.673300e-08,             -3.330800e-08,              3.838900e-08, 
                    0e+00,                     0e+00,                     0e+00,                     0e+00,                     0e+00, 
                    0e+00,                     0e+00,                     0e+00,                     0e+00, 
},
{
            -1.725200e-07,             -6.748600e-08,              6.147400e-08,              5.021200e-08,             -7.521100e-08, 
            -2.541200e-07,              7.604900e-09,              1.319500e-08,              8.571000e-08,             -6.601000e-08, 
            -6.404700e-09,             -1.149700e-07,              1.356200e-08,             -2.832000e-08,             -1.952000e-08, 
             2.375700e-08,              1.034100e-08,              2.014000e-08,              1.390500e-08,             -1.203000e-08, 
                    0e+00,                     0e+00,                     0e+00,                     0e+00,                     0e+00, 
                    0e+00,                     0e+00,                     0e+00,                     0e+00, 
},
{
             9.714600e-08,              3.475300e-07,              3.168100e-07,              2.491300e-07,             -2.757000e-07, 
             1.908500e-08,             -3.557500e-07,             -1.688700e-08,              1.227400e-07,              1.950400e-08, 
            -1.004000e-07,             -1.716600e-08,              1.997400e-08,             -1.599600e-08,             -1.361400e-08, 
             4.239900e-08,              7.820100e-09,              1.474500e-08,              8.805300e-09,             -3.942500e-08, 
                    0e+00,                     0e+00,                     0e+00,                     0e+00,                     0e+00, 
                    0e+00,                     0e+00,                     0e+00,                     0e+00, 
},
{
             8.256000e-08,             -9.975700e-10,              6.807400e-08,              1.145000e-08,             -2.493600e-07, 
            -3.174600e-08,             -6.195400e-08,              6.635700e-08,             -1.279300e-07,              1.022800e-07, 
            -4.038300e-08,              3.335800e-08,              2.461700e-08,              4.981800e-08,             -4.367500e-09, 
             3.304400e-08,             -3.275600e-08,             -3.353700e-08,              4.248300e-08,             -1.272100e-08, 
                    0e+00,                     0e+00,                     0e+00,                     0e+00,                     0e+00, 
                    0e+00,                     0e+00,                     0e+00,                     0e+00, 
},
{
             1.784000e-08,              6.541300e-08,              3.291000e-08,             -1.395500e-07,             -4.994200e-08, 
            -3.555600e-08,              3.902700e-08,             -1.303500e-07,              1.997000e-07,             -3.529200e-08, 
            -3.179900e-08,             -7.176800e-09,              3.399000e-08,             -5.248000e-08,              5.828800e-09, 
             5.032500e-09,              1.030500e-08,              2.818900e-08,              3.149100e-08,              2.588500e-08, 
                    0e+00,                     0e+00,                     0e+00,                     0e+00,                     0e+00, 
                    0e+00,                     0e+00,                     0e+00,                     0e+00, 
},
{
             1.335800e-08,              1.063200e-07,             -7.460300e-08,             -2.785700e-08,             -7.171300e-08, 
            -5.843400e-08,             -5.693800e-08,              1.403000e-08,              4.301200e-08,              1.263900e-07, 
             1.039900e-07,             -5.731200e-08,             -1.077100e-09,             -1.306500e-08,             -3.131500e-08, 
            -3.025500e-10,             -1.867500e-08,             -1.074200e-08,              1.115900e-08,              5.277900e-08, 
                    0e+00,                     0e+00,                     0e+00,                     0e+00,                     0e+00, 
                    0e+00,                     0e+00,                     0e+00,                     0e+00, 
},
{
            -3.416200e-08,              8.210900e-08,              4.651000e-09,             -2.433300e-08,             -1.128600e-08, 
             3.798700e-08,              5.214600e-09,              5.012500e-08,             -1.014700e-09,             -5.296500e-08, 
            -5.134300e-08,              6.381600e-08,             -9.557000e-09,              8.771100e-08,             -2.833200e-08, 
             2.130500e-08,             -1.275000e-10,              1.371900e-08,             -1.251900e-08,              1.616600e-08, 
             1.863200e-08,              3.676300e-08,             -1.395900e-08,             -5.064800e-08,             -5.379800e-09, 
             1.554000e-08,                     0e+00,                     0e+00,                     0e+00, 
},
{
             7.598300e-08,             -7.253200e-08,             -1.807700e-08,              5.393300e-08,             -1.244300e-07, 
             3.574000e-09,              2.686600e-08,             -1.875500e-08,             -2.916500e-08,              3.168500e-08, 
             5.754300e-09,              1.184300e-08,              3.258700e-09,              6.916600e-08,              4.772400e-08, 
            -3.907500e-09,             -5.648600e-10,              1.920200e-08,             -3.399300e-08,             -3.158500e-08, 
             1.506600e-08,              1.324600e-08,              2.161400e-08,             -8.493900e-09,              5.199200e-09, 
            -1.841000e-08,             -1.644900e-08,             -1.012400e-08,                     0e+00, 
},
{
             2.419100e-08,             -9.915500e-08,              6.779500e-08,             -4.281600e-08,             -3.227300e-08, 
             3.914800e-08,             -4.835100e-08,             -2.993900e-09,              3.170600e-10,              2.688900e-08, 
             4.834800e-08,             -3.511100e-08,             -3.537200e-08,             -6.078800e-08,             -2.208600e-09, 
            -2.602600e-08,             -5.735900e-08,              1.742900e-08,              1.637500e-08,             -1.857200e-08, 
            -1.247800e-08,              1.034200e-08,             -1.603500e-08,              2.778100e-09,             -1.068700e-08, 
             3.259300e-09,              2.994500e-08,              7.829800e-09,                     0e+00, 
},
{
            -5.022700e-08,             -7.799100e-09,             -1.650800e-08,              3.919900e-08,              6.663000e-08, 
             6.569300e-08,             -5.550800e-08,              4.766900e-08,             -3.103500e-08,              3.358100e-08, 
             2.724600e-08,              2.009200e-08,              1.048700e-08,              3.140700e-08,             -4.658400e-08, 
            -7.952200e-09,             -2.517400e-08,              1.443800e-08,             -3.815600e-08,             -2.101600e-08, 
             2.389100e-08,             -1.286700e-09,              1.906700e-08,              2.706100e-09,             -5.627000e-08, 
             1.238800e-08,              5.214300e-09,             -7.092200e-09,                     0e+00, 
},
{
             1.298800e-08,              1.164000e-08,              2.933200e-08,              9.368700e-08,             -1.164000e-08, 
             9.999800e-09,              6.621100e-08,              7.684700e-08,             -8.106400e-08,              2.549200e-08, 
            -5.570500e-09,             -1.049200e-08,             -1.337500e-08,             -2.981800e-08,              6.733000e-09, 
            -1.847000e-08,              4.914300e-08,             -3.142900e-08,             -7.496100e-08,              1.085300e-07, 
             2.357300e-09,             -9.394700e-08,              2.406900e-08,                     0e+00,                     0e+00, 
            -4.341300e-09,             -5.587900e-08,                     0e+00,                     0e+00, 
},
{
            -7.694700e-11,              2.196200e-08,             -3.957100e-08,             -3.905400e-08,             -4.643900e-09, 
            -3.706600e-08,              8.686800e-08,             -2.548100e-09,             -7.067200e-09,             -1.315400e-08, 
            -2.755500e-08,              3.741700e-08,              9.727700e-09,              1.368400e-08,             -3.956700e-08, 
            -2.327500e-08,             -4.500600e-08,             -1.150700e-08,             -3.641300e-09,             -4.168300e-08, 
                    0e+00,                     0e+00,                     0e+00,                     0e+00,                     0e+00, 
                    0e+00,                     0e+00,                     0e+00,                     0e+00, 
},
{
             1.320300e-08,              3.265500e-09,              5.985800e-08,             -1.028200e-08,              1.026300e-08, 
            -2.650700e-08,             -3.876400e-08,             -1.165800e-08,              1.082800e-07,              1.805400e-08, 
            -1.380700e-08,             -3.383100e-08,             -3.670500e-10,              1.860800e-08,             -2.094000e-08, 
             8.176100e-09,             -2.929100e-08,             -3.077500e-08,             -2.378200e-08,             -1.836800e-08, 
                    0e+00,                     0e+00,                     0e+00,                     0e+00,                     0e+00, 
                    0e+00,                     0e+00,                     0e+00,                     0e+00, 
},
{
             1.445300e-08,              5.576800e-09,              3.315600e-08,              1.949000e-08,              9.561500e-08, 
             2.928200e-08,             -1.175500e-08,             -9.216300e-09,              5.145900e-08,             -1.023300e-08, 
            -1.437900e-08,             -1.513100e-08,             -2.960400e-08,             -9.126300e-09,              1.723900e-08, 
            -4.829400e-08,              1.413100e-08,             -1.554600e-08,              5.763900e-09,              1.834300e-08, 
                    0e+00,                     0e+00,                     0e+00,                     0e+00,                     0e+00, 
                    0e+00,                     0e+00,                     0e+00,                     0e+00, 
},
{
            -4.591200e-09,             -2.751700e-08,             -1.370700e-07,              6.880800e-08,             -2.282100e-08, 
            -1.051100e-07,             -5.553200e-09,              1.138100e-07,             -1.065200e-08,             -2.890100e-08, 
            -8.453600e-09,             -8.238300e-09,              4.261700e-08,             -1.353700e-09,             -1.860200e-09, 
            -1.740400e-08,             -8.936700e-09,              1.947300e-08,              3.397400e-08,             -2.204900e-08, 
                    0e+00,                     0e+00,                     0e+00,                     0e+00,                     0e+00, 
                    0e+00,                     0e+00,                     0e+00,                     0e+00, 
},
{
            -9.930700e-10,                     0e+00,                     0e+00,                     0e+00,                     0e+00, 
                    0e+00,                     0e+00,                     0e+00,                     0e+00,                     0e+00, 
                    0e+00,                     0e+00,              1.050800e-09,              2.083200e-08,              9.546200e-09, 
            -2.606700e-10,             -1.572300e-08,                     0e+00,                     0e+00,                     0e+00, 
                    0e+00,                     0e+00,                     0e+00,                     0e+00,                     0e+00, 
                    0e+00,                     0e+00,                     0e+00,                     0e+00, 
},
{
             2.073800e-08,                     0e+00,                     0e+00,                     0e+00,                     0e+00, 
                    0e+00,                     0e+00,                     0e+00,                     0e+00,                     0e+00, 
                    0e+00,                     0e+00,              2.634900e-08,             -1.137000e-08,              2.194100e-08, 
             3.898900e-09,             -1.139500e-08,                     0e+00,                     0e+00,                     0e+00, 
                    0e+00,                     0e+00,                     0e+00,                     0e+00,                     0e+00, 
                    0e+00,                     0e+00,                     0e+00,                     0e+00, 
},
{
             6.139800e-09,                     0e+00,                     0e+00,                     0e+00,                     0e+00, 
                    0e+00,                     0e+00,                     0e+00,                     0e+00,                     0e+00, 
                    0e+00,                     0e+00,              1.354300e-08,             -1.851000e-08,             -1.166600e-08, 
             1.279400e-09,             -1.622400e-08,                     0e+00,                     0e+00,                     0e+00, 
                    0e+00,                     0e+00,                     0e+00,                     0e+00,                     0e+00, 
                    0e+00,                     0e+00,                     0e+00,                     0e+00, 
},
{
            -3.371600e-08,                     0e+00,                     0e+00,                     0e+00,                     0e+00, 
                    0e+00,                     0e+00,                     0e+00,                     0e+00,                     0e+00, 
                    0e+00,                     0e+00,             -2.322200e-08,             -2.474900e-08,              1.495500e-08, 
            -3.986500e-09,                     0e+00,                     0e+00,                     0e+00,                     0e+00, 
                    0e+00,                     0e+00,                     0e+00,                     0e+00,                     0e+00, 
                    0e+00,                     0e+00,                     0e+00,                     0e+00, 
},
{
            -3.219200e-09,                     0e+00,                     0e+00,                     0e+00,                     0e+00, 
                    0e+00,                     0e+00,                     0e+00,                     0e+00,                     0e+00, 
                    0e+00,                     0e+00,             -4.491400e-08,              6.597200e-09,             -2.330900e-08, 
             2.644700e-09,                     0e+00,                     0e+00,                     0e+00,                     0e+00, 
                    0e+00,                     0e+00,                     0e+00,                     0e+00,                     0e+00, 
                    0e+00,                     0e+00,                     0e+00,                     0e+00, 
},
{
                    0e+00,                     0e+00,                     0e+00,                     0e+00,                     0e+00, 
                    0e+00,                     0e+00,                     0e+00,                     0e+00,                     0e+00, 
                    0e+00,                     0e+00,             -6.401600e-08,             -6.313300e-09,             -2.597700e-08, 
             7.569000e-09,             -3.824100e-09,                     0e+00,                     0e+00,                     0e+00, 
                    0e+00,                     0e+00,                     0e+00,                     0e+00,                     0e+00, 
                    0e+00,                     0e+00,                     0e+00,                     0e+00, 
},
{
                    0e+00,                     0e+00,                     0e+00,                     0e+00,                     0e+00, 
                    0e+00,                     0e+00,                     0e+00,                     0e+00,                     0e+00, 
                    0e+00,                     0e+00,                     0e+00,              3.618600e-09,              1.198500e-08, 
             2.319200e-08,              5.888300e-08,                     0e+00,                     0e+00,                     0e+00, 
                    0e+00,                     0e+00,                     0e+00,                     0e+00,                     0e+00, 
                    0e+00,                     0e+00,              9.999900e-10,              8.999900e-09, 
},
{
                    0e+00,                     0e+00,                     0e+00,                     0e+00,                     0e+00, 
                    0e+00,                     0e+00,                     0e+00,                     0e+00,                     0e+00, 
                    0e+00,                     0e+00,                     0e+00,             -3.363800e-08,              1.528100e-08, 
             3.054700e-08,                     0e+00,                     0e+00,                     0e+00,                     0e+00, 
                    0e+00,                     0e+00,                     0e+00,                     0e+00,                     0e+00, 
                    0e+00,                     0e+00,              3.000000e-09,                     0e+00, 
},
{
                    0e+00,                     0e+00,                     0e+00,                     0e+00,                     0e+00, 
                    0e+00,                     0e+00,                     0e+00,                     0e+00,                     0e+00, 
                    0e+00,                     0e+00,                     0e+00,                     0e+00,                     0e+00, 
                    0e+00,                     0e+00,                     0e+00,                     0e+00,                     0e+00, 
                    0e+00,                     0e+00,                     0e+00,                     0e+00,                     0e+00, 
                    0e+00,                     0e+00,             -2.200000e-08,                     0e+00, 
},
} ;

gal_gm_t gal_gmwgs72 = {
GAL_SSB_EA,
"WGS-72",
3.986008e+14,
6.378135e+06,
28,
27,
1,
(double *) &gal_gmwgs72_terms
} ;

__END_DECLS  
  
#endif /* !_GAL_GMWGS72_H_ */ 

/*
 *  gal - General Astrodynamics Library  
 *  Copyright (C) 2008 Paul C. L. Willmott  
 *  
 *  This program is free software; you can redistribute it and/or modify  
 *  it under the terms of the GNU General Public License as published by  
 *  the Free Software Foundation; either version 2 of the License, or  
 *  (at your option) any later version.  
 *  
 *  This program is distributed in the hope that it will be useful,  
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of  
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the  
 *  GNU General Public License for more details.  
 *  
 *  You should have received a copy of the GNU General Public License along  
 *  with this program; if not, write to the Free Software Foundation, Inc.,  
 *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.  
 *    
 *  Contact:  
 *    
 *  Paul Willmott  
 *  vp9mu@amsat.org  
 */  
  
