/*  
 *  - - - - - - - - - - - - - -
 *   g a l _ g r a v i t y . h
 *  - - - - - - - - - - - - - -
 *  
 *  This header file is part of the General Astrodynamics Library  
 *
 *  Description:
 *
 *     This header file includes all of the component header files
 *     for the gravity sub-library.
 *  
 *  Status: 
 *  
 *     Sub-library header file  
 *
 *  Includes:  
 *
 *     gal_gm.h                       Header file for gravity model structures
 *     gal_gmuzh.h                    Compute un-normalized zonal harmonic
 *     gal_gmalloc.h                  Create gravity model structure
 *     gal_gmcpy.h                    Allocate and copy gravity model
 *     gal_gmget.h                    Get copy of selected gravity model   
 *     gal_gmfree.h                   Free gravity model 
 *     gal_gmwgs72.h                  WGS72 gravity model definition
 *     gal_gmwgs66.h                  WGS66 gravity model definition
 *     gal_gmjgm3.h                   JGM-3 gravity model definition
 *     gal_gmegm96.h                  EGM96 gravity model definition
 *     gal_gmmgnp120p.h               MGNP120PSAAP gravity model definition
 *     gal_gmmgnp180u.h               MGNP180U gravity model definition  
 *     gal_gmglgm1.h                  GLGM-1 gravity model definition
 *     gal_gmglgm2.h                  GLGM-2 gravity model definition
 *     gal_gmgmm2b.h                  GMM-2B gravity model definition
 *     gal_gmmgm1025.h                MGM1025 gravity model definition
 *     gal_gmnorm.h                   Normalize gravity model coefficients
 *     gal_gmdenorm.h                 Un-normalize gravity model coefficients 
 *     gal_stget.h                    Get spherical terms from gravity model
 *     gal_stset.h                    Set spherical terms in gravity model
 *     gal_stnf.h                     Compute spherical terms normalization factor
 *     gal_stunf.h                    Compute spherical terms un-normalization factor
 *     gal_tu.h                       Compute canonical unit TU factor
 *     gal_canpv                      Convert pv-vector to canonical units
 *     gal_uncanpv                    Convert pv-vector from canonical units
 *     gal_accsrps                    Acceleration due to solar radiation pressure (simplfied)
 *     gal_accsrp                     Acceleration due to solar radiation pressure 
 *  
 *  This revision:  
 * 
 *     2009 January 3  
 *  
 *  Copyright (C) 2008, 2009 Paul C. L. Willmott. See notes at end. 
 *  
 *-----------------------------------------------------------------------  
 */  

#ifndef _GAL_GRAVITY_H_  
#define _GAL_GRAVITY_H_ 1  
  
#include "gal_gm.h"
#include "gal_gmuzh.h"
#include "gal_gmalloc.h"
#include "gal_gmcpy.h"
#include "gal_gmget.h"
#include "gal_gmfree.h"
#include "gal_gmwgs72.h"
#include "gal_gmwgs66.h"
#include "gal_gmjgm3.h"
#include "gal_gmegm96.h"
#include "gal_gmmgnp120p.h"
#include "gal_gmmgnp180u.h"
#include "gal_gmglgm1.h"
#include "gal_gmglgm2.h"
#include "gal_gmgmm2b.h"
#include "gal_gmmgm1025.h"
#include "gal_gmnorm.h"
#include "gal_gmdenorm.h"
#include "gal_stget.h"
#include "gal_stset.h"
#include "gal_stnf.h"
#include "gal_stunf.h"
#include "gal_tu.h"
#include "gal_canpv.h"
#include "gal_uncanpv.h" 
#include "gal_accsrps.h"
#include "gal_accsrp.h"

#endif /* !_GAL_GRAVITY_H_ */ 

/*
 *  gal - General Astrodynamics Library  
 *  Copyright (C) 2008, 2009 Paul C. L. Willmott  
 *  
 *  This program is free software; you can redistribute it and/or modify  
 *  it under the terms of the GNU General Public License as published by  
 *  the Free Software Foundation; either version 2 of the License, or  
 *  (at your option) any later version.  
 *  
 *  This program is distributed in the hope that it will be useful,  
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of  
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the  
 *  GNU General Public License for more details.  
 *  
 *  You should have received a copy of the GNU General Public License along  
 *  with this program; if not, write to the Free Software Foundation, Inc.,  
 *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.  
 *    
 *  Contact:  
 *    
 *  Paul Willmott  
 *  vp9mu@amsat.org  
 */  
  
