/*  
 *  - - - - - - - - - - -  
 *   g a l _ j d 2 c a l  
 *  - - - - - - - - - - -  
 *  
 *  This routine is part of the General Astrodynamics Library  
 *  
 *  Description: 
 *  
 *  Julian Date to Gregorian year, month, day, and fraction of a day.  
 *  
 *  This routine is an independent translation of a FORTRAN routine  
 *  that is part of IAU's SOFA software collection.  
 *  
 *  Status:
 *  
 *     support routine.  
 *  
 *  Given:
 *  
 *     dj1,dj2             d        Julian Date (Notes 1, 2)  
 *  
 *  Returned:
 *  
 *     *iy                 i        year  
 *     *im                 i        month  
 *     *id                 i        day  
 *     *fd                 d        fraction of day  
 *     gal_jd2cal          i        status:  
 *                                    0 = OK  
 *                                   -1 = unacceptable date (Note 3)  
 *  
 *  Notes:  
 *  
 *  1) The earliest valid date is -68569.5 (-4900 March 1).  The  
 *     largest value accepted is 10^9.  
 *  
 *  2) The Julian Date is apportioned in any convenient way between  
 *     the arguments dj1 and dj2.  For example, JD=2450123.7 could  
 *     be expressed in any of these ways, among others:  
 *  
 *             dj1            dj2  
 *  
 *         2450123.7          0.0        (JD method)  
 *         2451545.0      -1421.3        (J2000 method)  
 *         2400000.5      50123.2        (MJD method)  
 *         2450123.5          0.2        (date & time method)  
 *  
 *  3) In early eras the conversion is from the "Proleptic Gregorian  
 *     Calendar";  no account is taken of the date(s) of adoption of  
 *     the Gregorian Calendar, nor is the AD/BC numbering convention  
 *     observed.  
 *  
 *  References:  
 *  
 *     Explanatory Supplement to the Astronomical Almanac,  
 *     P. Kenneth Seidelmann (ed), University Science Books (1992),  
 *     Section 12.92 (p604).  
 *  
 *  This revision:
 *  
 *     2001 September 16 ( c version 2008 June 8 )  
 *  
 *  
 *  Copyright (C) 2008 Paul C. L. Willmott. See notes at end.  
 *  
 *-----------------------------------------------------------------------  
 */  
  
#ifndef _GAL_JD2CAL_H_  
#define _GAL_JD2CAL_H_ 1  

#undef __BEGIN_DECLS  
#undef __END_DECLS  
#ifdef __cplusplus  
#define __BEGIN_DECLS extern "C" {  
#define __END_DECLS }  
#else  
#define __BEGIN_DECLS /* empty */  
#define __END_DECLS   /* empty */  
#endif
  
__BEGIN_DECLS  
  
int  
gal_jd2cal  
 (  
    double dj1,  
    double dj2,  
    int *iy,  
    int *im,  
    int *id,  
    double *fd
 ) ;  
  
__END_DECLS  
  
#endif /* !_GAL_JD2CAL_H_ */  

/*  
 *  gal - General Astrodynamics Library  
 *  Copyright (C) 2008 Paul C. L. Willmott  
 *  
 *  This program is free software; you can redistribute it and/or modify  
 *  it under the terms of the GNU General Public License as published by  
 *  the Free Software Foundation; either version 2 of the License, or  
 *  (at your option) any later version.  
 *  
 *  This program is distributed in the hope that it will be useful,  
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of  
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the  
 *  GNU General Public License for more details.  
 *  
 *  You should have received a copy of the GNU General Public License along  
 *  with this program; if not, write to the Free Software Foundation, Inc.,  
 *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.  
 *  
 *  Contact:  
 *  
 *  Paul Willmott  
 *  vp9mu@amsat.org  
 */  
