/*  
 *  - - - - - - - -  
 *   g a l _ p 2 s  
 *  - - - - - - - -  
 *  
 *  This routine is part of the General Astrodynamics Library  
 *  
 *  Description: 
 *  
 *  P-vector to spherical polar coordinates.  
 *  
 *  This routine is an independent translation of a FORTRAN routine  
 *  that is part of IAU's SOFA software collection.  
 *  
 *  Status:
 *  
 *     vector/matrix support routine.  
 *  
 *  Given:
 *  
 *     p                  d[3]      p-vector  
 *  
 *  Returned:
 *  
 *     *theta              d        longitude angle (radians)  
 *     *phi                d        latitude angle (radians)  
 *     *r                  d        radial distance  
 *  
 *  Notes:  
 *  
 *  1) If p is null, zero theta, phi and r are returned.  
 *  
 *  2) At either pole, zero theta is returned.  
 *  
 *  Called:
 *  
 *     gal_c2s            p-vector to spherical  
 *     gal_pm             modulus of p-vector  
 *  
 *  This revision:
 *  
 *     2006 November 13 ( c version 2008 February 4 )  
 *  
 *  
 *  Copyright (C) 2008 Paul C. L. Willmott. See notes at end.  
 *  
 *-----------------------------------------------------------------------  
 */  
  
#ifndef _GAL_P2S_H_  
#define _GAL_P2S_H_ 1  

#undef __BEGIN_DECLS  
#undef __END_DECLS  
#ifdef __cplusplus  
#define __BEGIN_DECLS extern "C" {  
#define __END_DECLS }  
#else  
#define __BEGIN_DECLS /* empty */  
#define __END_DECLS   /* empty */  
#endif
  
__BEGIN_DECLS  
  
void  
gal_p2s  
 (  
    double p[3],  
    double *theta,  
    double *phi,  
    double *r  
 ) ;  
  
__END_DECLS  
  
#endif /* !_GAL_P2S_H_ */  

/*  
 *  gal - General Astrodynamics Library  
 *  Copyright (C) 2008 Paul C. L. Willmott  
 *  
 *  This program is free software; you can redistribute it and/or modify  
 *  it under the terms of the GNU General Public License as published by  
 *  the Free Software Foundation; either version 2 of the License, or  
 *  (at your option) any later version.  
 *  
 *  This program is distributed in the hope that it will be useful,  
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of  
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the  
 *  GNU General Public License for more details.  
 *  
 *  You should have received a copy of the GNU General Public License along  
 *  with this program; if not, write to the Free Software Foundation, Inc.,  
 *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.  
 *  
 *  Contact:  
 *  
 *  Paul Willmott  
 *  vp9mu@amsat.org  
 */  
