/*  
 *  - - - - - - - - -
 *   g a l _ p a d l
 *  - - - - - - - - -
 *  
 *  This routine is part of the General Astrodynamics Library  
 *
 *  Description:
 *
 *     This routine copies a maximum of l characters from the right side of
 *     s2 to s1. If the length of s2 is less than l then the left hand side
 *     is padded with spaces upto the required length l.   
 *  
 *  Status: 
 *  
 *     String manipulation routine  
 *  
 *  Given:  
 *
 *     *s1             c[]          Target string
 *     *s2             c[]          Source string 
 *     l                i           Required target length
 *  
 *  Returned:  
 *  
 *     *gal_padl       *c           Pointer to the start of the target string
 *  
 *  Notes:  
 *
 *  1) The target string s1 must be at least the same length as the source 
 *     string s2.
 *
 *  Called:
 *
 *     gal_rightstr                 Copy right side of string
 *
 *  This revision:  
 * 
 *     2008 March 8 
 *  
 *  Copyright (C) 2008 Paul C. L. Willmott. See notes at end. 
 *  
 *-----------------------------------------------------------------------  
 */  

#ifndef _GAL_PADL_H_  
#define _GAL_PADL_H_ 1  
  
#undef  __BEGIN_DECLS  
#undef  __END_DECLS  
#ifdef  __cplusplus  
#define __BEGIN_DECLS extern "C" {  
#define __END_DECLS }  
#else  
#define __BEGIN_DECLS /* empty */  
#define __END_DECLS   /* empty */  
#endif
  
__BEGIN_DECLS  

char *
gal_padl
  (
    char *s1,
	char *s2,
	int  l
  ) ;	  
 
__END_DECLS  
  
#endif /* !_GAL_PADL_H_ */ 

/*
 *  gal - General Astrodynamics Library  
 *  Copyright (C) 2008 Paul C. L. Willmott  
 *  
 *  This program is free software; you can redistribute it and/or modify  
 *  it under the terms of the GNU General Public License as published by  
 *  the Free Software Foundation; either version 2 of the License, or  
 *  (at your option) any later version.  
 *  
 *  This program is distributed in the hope that it will be useful,  
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of  
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the  
 *  GNU General Public License for more details.  
 *  
 *  You should have received a copy of the GNU General Public License along  
 *  with this program; if not, write to the Free Software Foundation, Inc.,  
 *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.  
 *    
 *  Contact:  
 *    
 *  Paul Willmott  
 *  vp9mu@amsat.org  
 */  
  
