/*  
 *  - - - - - - - -  
 *   g a l _ p a s  
 *  - - - - - - - -  
 *  
 *  This routine is part of the General Astrodynamics Library  
 *  
 *  Description: 
 *  
 *  Position-angle from spherical coordinates.  
 *  
 *  This routine is an independent translation of a FORTRAN routine  
 *  that is part of IAU's SOFA software collection.  
 *  
 *  Status:
 *  
 *     vector/matrix support routine.  
 *  
 *  Given:
 *  
 *     al                  d        longitude of point A (e.g. RA) in radians  
 *     ap                  d        latitude of point A (e.g. Dec) in radians  
 *     bl                  d        longitude of point B  
 *     bp                  d        latitude of point B  
 *  
 *  Returned:
 *  
 *     gal_pas             d        position angle of B with respect to A  
 *  
 *  Notes:  
 *  
 *  1) The result is the bearing (position angle), in radians, of point  
 *     B with respect to point A.  It is in the range -pi to +pi.  The  
 *     sense is such that if B is a small distance "east" of point A,  
 *     the bearing is approximately +pi/2.  
 *  
 *  2) Zero is returned if the two points are coincident.  
 *  
 *  This revision:
 *  
 *     2000 November 25 ( c version 2008 June 8 )  
 *  
 *  
 *  Copyright (C) 2008 Paul C. L. Willmott. See notes at end.  
 *  
 *-----------------------------------------------------------------------  
 */  
  
#ifndef _GAL_PAS_H_  
#define _GAL_PAS_H_ 1  

#undef __BEGIN_DECLS  
#undef __END_DECLS  
#ifdef __cplusplus  
#define __BEGIN_DECLS extern "C" {  
#define __END_DECLS }  
#else  
#define __BEGIN_DECLS /* empty */  
#define __END_DECLS   /* empty */  
#endif
  
__BEGIN_DECLS  
  
double 
gal_pas  
 (  
    double al,  
    double ap,  
    double bl,  
    double bp 
 ) ;  
  
__END_DECLS  
  
#endif /* !_GAL_PAS_H_ */  

/*  
 *  gal - General Astrodynamics Library  
 *  Copyright (C) 2008 Paul C. L. Willmott  
 *  
 *  This program is free software; you can redistribute it and/or modify  
 *  it under the terms of the GNU General Public License as published by  
 *  the Free Software Foundation; either version 2 of the License, or  
 *  (at your option) any later version.  
 *  
 *  This program is distributed in the hope that it will be useful,  
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of  
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the  
 *  GNU General Public License for more details.  
 *  
 *  You should have received a copy of the GNU General Public License along  
 *  with this program; if not, write to the Free Software Foundation, Inc.,  
 *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.  
 *  
 *  Contact:  
 *  
 *  Paul Willmott  
 *  vp9mu@amsat.org  
 */  
