/*  
 *  - - - - - - - - - -  
 *   g a l _ p v d p v  
 *  - - - - - - - - - -  
 *  
 *  This routine is part of the General Astrodynamics Library  
 *  
 *  Description: 
 *  
 *  Inner (=scalar=dot) product of two pv-vectors.  
 *  
 *  This routine is an independent translation of a FORTRAN routine  
 *  that is part of IAU's SOFA software collection.  
 *  
 *  Status:
 *  
 *     vector/matrix support routine.  
 *  
 *  Given:
 *  
 *     a                d[2][3]     first pv-vector  
 *     b                d[2][3]     second pv-vector  
 *  
 *  Returned:
 *  
 *     adb                d[2]      a . b (see note)  
 *  
 *  Notes:  
 *  
 *  1) If the position and velocity components of the two pv-vectors are  
 *     ( ap, av ) and ( bp, bv ), the result, a . b, is the pair of  
 *     numbers ( ap . bp , ap . bv + av . bp ).  The two numbers are the  
 *     dot-product of the two p-vectors and its derivative.  
 *  
 *  Called:
 *  
 *     gal_pdp            scalar product of two p-vectors  
 *  
 *  This revision:
 *  
 *     2006 November 13 ( c version 2008 February 4 )  
 *  
 *  
 *  Copyright (C) 2008 Paul C. L. Willmott. See notes at end.  
 *  
 *-----------------------------------------------------------------------  
 */  
  
#ifndef _GAL_PVDPV_H_  
#define _GAL_PVDPV_H_ 1  

#undef __BEGIN_DECLS  
#undef __END_DECLS  
#ifdef __cplusplus  
#define __BEGIN_DECLS extern "C" {  
#define __END_DECLS }  
#else  
#define __BEGIN_DECLS /* empty */  
#define __END_DECLS   /* empty */  
#endif
  
__BEGIN_DECLS  
  
void  
gal_pvdpv  
 (  
    double a[2][3],  
    double b[2][3],  
    double adb[2]  
 ) ;  
  
__END_DECLS  
  
#endif /* !_GAL_PVDPV_H_ */  

/*  
 *  gal - General Astrodynamics Library  
 *  Copyright (C) 2008 Paul C. L. Willmott  
 *  
 *  This program is free software; you can redistribute it and/or modify  
 *  it under the terms of the GNU General Public License as published by  
 *  the Free Software Foundation; either version 2 of the License, or  
 *  (at your option) any later version.  
 *  
 *  This program is distributed in the hope that it will be useful,  
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of  
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the  
 *  GNU General Public License for more details.  
 *  
 *  You should have received a copy of the GNU General Public License along  
 *  with this program; if not, write to the Free Software Foundation, Inc.,  
 *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.  
 *  
 *  Contact:  
 *  
 *  Paul Willmott  
 *  vp9mu@amsat.org  
 */  
