/*  
 *  - - - - - - - -  
 *   g a l _ p v u  
 *  - - - - - - - -  
 *  
 *  This routine is part of the General Astrodynamics Library  
 *  
 *  Description: 
 *  
 *  Update a pv-vector.  
 *  
 *  This routine is an independent translation of a FORTRAN routine  
 *  that is part of IAU's SOFA software collection.  
 *  
 *  Status:
 *  
 *     vector/matrix support routine.  
 *  
 *  Given:
 *  
 *     dt                  d        time interval  
 *     pv               d[2][3]     pv-vector  
 *  
 *  Returned:
 *  
 *     upv              d[2][3]     p updated, v unchanged  
 *  
 *  Notes:  
 *  
 *  1) "Update" means "refer the position component of the vector  
 *     to a new epoch dt time units from the existing epoch".  
 *  
 *  2) The time units of dt must match those of the velocity.  
 *  
 *  Called:
 *  
 *     gal_ppsp           p-vector plus scaled p-vector  
 *     gal_cp             copy p-vector  
 *  
 *  This revision:
 *  
 *     2003 January 14 ( c version 2008 February 4 )  
 *  
 *  
 *  Copyright (C) 2008 Paul C. L. Willmott. See notes at end.  
 *  
 *-----------------------------------------------------------------------  
 */  
  
#ifndef _GAL_PVU_H_  
#define _GAL_PVU_H_ 1  

#undef __BEGIN_DECLS  
#undef __END_DECLS  
#ifdef __cplusplus  
#define __BEGIN_DECLS extern "C" {  
#define __END_DECLS }  
#else  
#define __BEGIN_DECLS /* empty */  
#define __END_DECLS   /* empty */  
#endif
  
__BEGIN_DECLS  
  
void  
gal_pvu  
 (  
    double dt,  
    double pv[2][3],  
    double upv[2][3]  
 ) ;  
  
__END_DECLS  
  
#endif /* !_GAL_PVU_H_ */  

/*  
 *  gal - General Astrodynamics Library  
 *  Copyright (C) 2008 Paul C. L. Willmott  
 *  
 *  This program is free software; you can redistribute it and/or modify  
 *  it under the terms of the GNU General Public License as published by  
 *  the Free Software Foundation; either version 2 of the License, or  
 *  (at your option) any later version.  
 *  
 *  This program is distributed in the hope that it will be useful,  
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of  
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the  
 *  GNU General Public License for more details.  
 *  
 *  You should have received a copy of the GNU General Public License along  
 *  with this program; if not, write to the Free Software Foundation, Inc.,  
 *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.  
 *  
 *  Contact:  
 *  
 *  Paul Willmott  
 *  vp9mu@amsat.org  
 */  
