/*  
 *  - - - - - - - - - - - -
 *   g a l _ r e p l a c e
 *  - - - - - - - - - - - -
 *  
 *  This routine is part of the General Astrodynamics Library  
 *
 *  Description:
 *
 *     This routine copys the source string s2 to the target string s1. 
 *     Then replaces all occurrences of the sub-string s3 in s1 with 
 *     substring s4.
 *  
 *  Status: 
 *  
 *     String manipulation routine  
 *  
 *  Given:  
 *
 *     *s1             c[]          Target string
 *     *s2             c[]          Source string
 *     *s3             c[]          Substring to replace
 *     *s4             c[]          Replacement substring 
 *  
 *  Returned:  
 *  
 *     *gal_replace     *c          Pointer to the start of the target string
 *  
 *  Called:
 *
 *     gal_instr                    Find substring in string
 *     gal_delete                   Delete substring from string
 *     gal_insert                   Insert substring into string
 *
 *  This revision:  
 * 
 *     2008 March 8  
 *  
 *  Copyright (C) 2008 Paul C. L. Willmott. See notes at end. 
 *  
 *-----------------------------------------------------------------------  
 */  

#ifndef _GAL_REPLACE_H_  
#define _GAL_REPLACE_H_ 1  
  
#undef  __BEGIN_DECLS  
#undef  __END_DECLS  
#ifdef  __cplusplus  
#define __BEGIN_DECLS extern "C" {  
#define __END_DECLS }  
#else  
#define __BEGIN_DECLS /* empty */  
#define __END_DECLS   /* empty */  
#endif
  
__BEGIN_DECLS  

char *
gal_replace
  (
    char *s1,
    char *s2,
    char *s3,
    char *s4
  ) ;	  
 
__END_DECLS  
  
#endif /* !_GAL_REPLACE_H_ */ 

/*
 *  gal - General Astrodynamics Library  
 *  Copyright (C) 2008 Paul C. L. Willmott  
 *  
 *  This program is free software; you can redistribute it and/or modify  
 *  it under the terms of the GNU General Public License as published by  
 *  the Free Software Foundation; either version 2 of the License, or  
 *  (at your option) any later version.  
 *  
 *  This program is distributed in the hope that it will be useful,  
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of  
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the  
 *  GNU General Public License for more details.  
 *  
 *  You should have received a copy of the GNU General Public License along  
 *  with this program; if not, write to the Free Software Foundation, Inc.,  
 *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.  
 *    
 *  Contact:  
 *    
 *  Paul Willmott  
 *  vp9mu@amsat.org  
 */  
  
