/*  
 *  - - - - - - - - -  
 *   g a l _ r m 2 v  
 *  - - - - - - - - -  
 *  
 *  This routine is part of the General Astrodynamics Library  
 *  
 *  Description: 
 *  
 *  Express an r-matrix as an r-vector.  
 *  
 *  
 *  This routine is an independent translation of a FORTRAN routine  
 *  that is part of IAU's SOFA software collection.  
 *  
 *  Status:
 *  
 *     vector/matrix support routine.  
 *  
 *  Given:
 *  
 *     r                d[3][3]     rotation matrix  
 *  
 *  Returned:
 *  
 *     w                  d[3]      rotation vector (Note 1)  
 *  
 *  Notes:  
 *  
 *  1) A rotation matrix describes a rotation through some angle about  
 *     some arbitrary axis called the Euler axis.  The "rotation vector"  
 *     returned by this routine has the same direction as the Euler axis,  
 *     and its magnitude is the angle in radians.  (The magnitude and  
 *     direction can be separated by means of the routine gal_pn.)  
 *  
 *  2) If r is null, so is the result.  If r is not a rotation matrix  
 *     the result is undefined.  r must be proper (i.e. have a positive  
 *     determinant) and real orthogonal (inverse = transpose).  
 *  
 *  3) The reference frame rotates clockwise as seen looking along  
 *     the rotation vector from the origin.  
 *  
 *  This revision:
 *  
 *     2006 April 13 ( c version 2008 June 8 )  
 *  
 *  
 *  Copyright (C) 2008 Paul C. L. Willmott. See notes at end.  
 *  
 *-----------------------------------------------------------------------  
 */  
  
#ifndef _GAL_RM2V_H_  
#define _GAL_RM2V_H_ 1  

#undef __BEGIN_DECLS  
#undef __END_DECLS  
#ifdef __cplusplus  
#define __BEGIN_DECLS extern "C" {  
#define __END_DECLS }  
#else  
#define __BEGIN_DECLS /* empty */  
#define __END_DECLS   /* empty */  
#endif
  
__BEGIN_DECLS  
  
void  
gal_rm2v  
 (  
    double r[3][3],  
    double w[3]  
 ) ;  
  
__END_DECLS  
  
#endif /* !_GAL_RM2V_H_ */  

/*  
 *  gal - General Astrodynamics Library  
 *  Copyright (C) 2008 Paul C. L. Willmott  
 *  
 *  This program is free software; you can redistribute it and/or modify  
 *  it under the terms of the GNU General Public License as published by  
 *  the Free Software Foundation; either version 2 of the License, or  
 *  (at your option) any later version.  
 *  
 *  This program is distributed in the hope that it will be useful,  
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of  
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the  
 *  GNU General Public License for more details.  
 *  
 *  You should have received a copy of the GNU General Public License along  
 *  with this program; if not, write to the Free Software Foundation, Inc.,  
 *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.  
 *  
 *  Contact:  
 *  
 *  Paul Willmott  
 *  vp9mu@amsat.org  
 */  
