/*  
 *  - - - - - - -  
 *   g a l _ r y  
 *  - - - - - - -  
 *  
 *  This routine is part of the General Astrodynamics Library  
 *  
 *  Description: 
 *  
 *  Rotate an r-matrix about the y-axis.  
 *  
 *  This routine is an independent translation of a FORTRAN routine  
 *  that is part of IAU's SOFA software collection.  
 *  
 *  Status:
 *  
 *     vector/matrix support routine.  
 *  
 *  Given:
 *  
 *     theta               d        angle (radians)  
 *  
 *  Given and returned:  
 *     r                d[3][3]     r-matrix  
 *  
 *  Notes:  
 *  
 *  1) Sign convention: The matrix can be used to rotate the  
 *     reference frame of a vector.  Calling this routine with  
 *     positive theta incorporates in the matrix an additional  
 *     rotation, about the y-axis, anticlockwise as seen looking  
 *     towards the origin from positive y.  
 *  
 *  Called:
 *  
 *     gal_ir             initialize r-matrix to identity  
 *     gal_rxr            product of two r-matrices  
 *     gal_cr             copy r-matrix  
 *  
 *  This revision:
 *  
 *     2006 November 13 ( c version 2008 June 8 )  
 *  
 *  
 *  Copyright (C) 2008 Paul C. L. Willmott. See notes at end.  
 *  
 *-----------------------------------------------------------------------  
 */  
  
#ifndef _GAL_RY_H_  
#define _GAL_RY_H_ 1  

#undef __BEGIN_DECLS  
#undef __END_DECLS  
#ifdef __cplusplus  
#define __BEGIN_DECLS extern "C" {  
#define __END_DECLS }  
#else  
#define __BEGIN_DECLS /* empty */  
#define __END_DECLS   /* empty */  
#endif
  
__BEGIN_DECLS  
  
void  
gal_ry  
 (  
    double theta,  
    double r[3][3]  
 ) ;  
  
__END_DECLS  
  
#endif /* !_GAL_RY_H_ */  

/*  
 *  gal - General Astrodynamics Library  
 *  Copyright (C) 2008 Paul C. L. Willmott  
 *  
 *  This program is free software; you can redistribute it and/or modify  
 *  it under the terms of the GNU General Public License as published by  
 *  the Free Software Foundation; either version 2 of the License, or  
 *  (at your option) any later version.  
 *  
 *  This program is distributed in the hope that it will be useful,  
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of  
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the  
 *  GNU General Public License for more details.  
 *  
 *  You should have received a copy of the GNU General Public License along  
 *  with this program; if not, write to the Free Software Foundation, Inc.,  
 *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.  
 *  
 *  Contact:  
 *  
 *  Paul Willmott  
 *  vp9mu@amsat.org  
 */  
