/*  
 *  - - - - - - - - - 
 *   g a l _ s e z m  
 *  - - - - - - - - - 
 *  
 *  Form SEZ transformation matrix  
 *  
 *  Description: 
 *  
 *     This routine forms the SEZ transformation matrix for specified
 *     latitude and longitude. 
 *  
 *  Status:
 *  
 *     support routine.  
 *  
 *  Given:
 *  
 *     lat                 d        Latitude ( radians )
 *     lon                 d        Longitude ( radians )
 *  
 *  Returned:
 *  
 *     sez              d[3][3]     SEZ matrix
 *  
 *  References:
 *
 *     Methods of Orbit Determination
 *     P. R. Escobal 1965
 *     Pages 405-406
 *
 *  This revision:
 *  
 *     2009 January 9   
 *  
 *  Copyright (C) 2009 Paul C. L. Willmott. See notes at end.  
 *  
 *-----------------------------------------------------------------------  
 */  
  
#ifndef _GAL_SEZM_H_  
#define _GAL_SEZM_H_ 1  

#undef __BEGIN_DECLS  
#undef __END_DECLS  
#ifdef __cplusplus  
#define __BEGIN_DECLS extern "C" {  
#define __END_DECLS }  
#else  
#define __BEGIN_DECLS /* empty */  
#define __END_DECLS   /* empty */  
#endif
  
__BEGIN_DECLS  
  
void  
gal_sezm  
 ( 
   double latitude,
   double longitude,
   double sez[3][3]
 ) ;  
  
__END_DECLS  
  
#endif /* !_GAL_SEZM_H_ */  

/*  
 *  gal - General Astrodynamics Library  
 *  Copyright (C) 2009 Paul C. L. Willmott  
 *  
 *  This program is free software; you can redistribute it and/or modify  
 *  it under the terms of the GNU General Public License as published by  
 *  the Free Software Foundation; either version 2 of the License, or  
 *  (at your option) any later version.  
 *  
 *  This program is distributed in the hope that it will be useful,  
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of  
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the  
 *  GNU General Public License for more details.  
 *  
 *  You should have received a copy of the GNU General Public License along  
 *  with this program; if not, write to the Free Software Foundation, Inc.,  
 *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.  
 *  
 *  Contact:  
 *  
 *  Paul Willmott  
 *  vp9mu@amsat.org  
 */  
