/*  
 *  - - - - - - - - - - 
 *   g a l _ s t g e t    
 *  - - - - - - - - - -  
 *  
 *  This routine is part of the General Astrodynamics Library  
 *
 *  Description:
 *
 *     This routine gets spherical terms C & S of degree n and order m
 *     from the given gravity model 
 *  
 *  Status: 
 *  
 *     support routine.  
 *  
 *  Given:  
 *
 *     n                i           required degree
 *     m                i           required order
 *     *gm           gal_gm_t       pointer to gravity model structure     
 *  
 *  Returned:  
 *  
 *     *c               d           C coefficient
 *     *s               d           S coefficient
 *     gal_stget        i           0 = success 
 *                                  1 = degree or order out of range
 *  
 *  Notes:  
 *  
 *  1) Gravitational coefficients C, S are efficiently stored in a single array CS. The lower 
 *     triangle matrix CS holds the non-sectorial C coefficients C[n][m] ( n != m ). Sectorial C 
 *     coefficients C[n][n] are the diagonal elements of CS and the upper triangular matrix 
 *     stores the S[n][m] ( m != 0 ) coefficients in columns, for the same degree n. Mapping of 
 *     CS to C, S is achieved through C[n][m] = CS[n][m], S[n][m] = CS[m-1][n].
 *  
 *  This revision:  
 * 
 *     2008 March 22 
 *  
 *  Copyright (C) 2008 Paul C. L. Willmott. See notes at end. 
 *  
 *-----------------------------------------------------------------------  
 */  

#ifndef _GAL_STGET_H_  
#define _GAL_STGET_H_ 1  

#include "gal_gm.h"
  
#undef  __BEGIN_DECLS  
#undef  __END_DECLS  
#ifdef  __cplusplus  
#define __BEGIN_DECLS extern "C" {  
#define __END_DECLS }  
#else  
#define __BEGIN_DECLS /* empty */  
#define __END_DECLS   /* empty */  
#endif
  
__BEGIN_DECLS  

int
gal_stget
  (
    const int n,
    const int m,
    gal_gm_t *gm,
    double *c,
    double *s
  ) ;    
 
__END_DECLS  
  
#endif /* !_GAL_STGET_ */ 

/*
 *  gal - General Astrodynamics Library  
 *  Copyright (C) 2008 Paul C. L. Willmott  
 *  
 *  This program is free software; you can redistribute it and/or modify  
 *  it under the terms of the GNU General Public License as published by  
 *  the Free Software Foundation; either version 2 of the License, or  
 *  (at your option) any later version.  
 *  
 *  This program is distributed in the hope that it will be useful,  
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of  
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the  
 *  GNU General Public License for more details.  
 *  
 *  You should have received a copy of the GNU General Public License along  
 *  with this program; if not, write to the Free Software Foundation, Inc.,  
 *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.  
 *    
 *  Contact:  
 *    
 *  Paul Willmott  
 *  vp9mu@amsat.org  
 */  
  
