/*  
 *  - - - - - - - - - 
 *   g a l _ t 2 p a   
 *  - - - - - - - - - 
 *  
 *  This routine is part of the General Astrodynamics Library  
 *
 *  Description:
 *
 *     This routine calculates the parabolic anomaly from time dt.
 *  
 *  Status: 
 *  
 *     Classical Model.  
 *  
 *  Given:  
 *
 *     gm             double        Gravitional parameter
 *     dt             double        Time since periapsis ( seconds )
 *     p              double        Semi parameter ( meters )
 *  
 *  Returned:  
 *  
 *     gal_t2pa        d           Parabolic anomaly ( radians )
 *
 *  Notes:
 *
 *  1) This routine is valid for parabolic trajectories only.
 *
 *  References:
 *
 *     Fundamentals of Astrodynamics and Applications
 *     Vallado, David A. Second Edition 2004
 *     Pages 75-78
 *
 *  This revision:  
 * 
 *     2009 January 2 
 *  
 *  Copyright (C) 2009 Paul C. L. Willmott. See notes at end. 
 *  
 *-----------------------------------------------------------------------  
 */  

#ifndef _GAL_T2PA_H_  
#define _GAL_T2PA_H_ 1  

  
#undef  __BEGIN_DECLS  
#undef  __END_DECLS  
#ifdef  __cplusplus  
#define __BEGIN_DECLS extern "C" {  
#define __END_DECLS }  
#else  
#define __BEGIN_DECLS /* empty */  
#define __END_DECLS   /* empty */  
#endif
  
__BEGIN_DECLS  

double
gal_t2pa
  (
    double gm,
    double dt,
    double p
  ) ;
 
__END_DECLS  
  
#endif /* !_GAL_T2PA_H_ */ 

/*
 *  gal - General Astrodynamics Library  
 *  Copyright (C) 2009 Paul C. L. Willmott  
 *  
 *  This program is free software; you can redistribute it and/or modify  
 *  it under the terms of the GNU General Public License as published by  
 *  the Free Software Foundation; either version 2 of the License, or  
 *  (at your option) any later version.  
 *  
 *  This program is distributed in the hope that it will be useful,  
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of  
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the  
 *  GNU General Public License for more details.  
 *  
 *  You should have received a copy of the GNU General Public License along  
 *  with this program; if not, write to the Free Software Foundation, Inc.,  
 *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.  
 *    
 *  Contact:  
 *    
 *  Paul Willmott  
 *  vp9mu@amsat.org  
 */  
  
