/*  
 *  - - - - - - - - - - 
 *   g a l _ t a 2 h a   
 *  - - - - - - - - - - 
 *  
 *  This routine is part of the General Astrodynamics Library  
 *
 *  Description:
 *
 *     This routine calculates the hyperbolic anomaly from true anomaly.
 *  
 *  Status: 
 *  
 *     Classical Model.  
 *  
 *  Given:  
 *
 *     ta             double        True anomaly ( radians )
 *     ecc            double        Eccentricity
 *  
 *  Returned:  
 *  
 *     gal_ta2ha        d           Hyperbolic anomaly ( radians )
 *
 *  Notes:
 *
 *  1) This routine is valid for hyperbolic orbits only.
 *
 *  References:
 *
 *     Fundamentals of Astrodynamics and Applications
 *     Vallado, David A. Second Edition 2004
 *     Page 85
 *
 *  This revision:  
 * 
 *     2009 January 2 
 *  
 *  Copyright (C) 2009 Paul C. L. Willmott. See notes at end. 
 *  
 *-----------------------------------------------------------------------  
 */  

#ifndef _GAL_TA2HA_H_  
#define _GAL_TA2HA_H_ 1  

  
#undef  __BEGIN_DECLS  
#undef  __END_DECLS  
#ifdef  __cplusplus  
#define __BEGIN_DECLS extern "C" {  
#define __END_DECLS }  
#else  
#define __BEGIN_DECLS /* empty */  
#define __END_DECLS   /* empty */  
#endif
  
__BEGIN_DECLS  

double
gal_ta2ha
  (
    double ta,
    double ecc
  ) ;
 
__END_DECLS  
  
#endif /* !_GAL_TA2HA_H_ */ 

/*
 *  gal - General Astrodynamics Library  
 *  Copyright (C) 2009 Paul C. L. Willmott  
 *  
 *  This program is free software; you can redistribute it and/or modify  
 *  it under the terms of the GNU General Public License as published by  
 *  the Free Software Foundation; either version 2 of the License, or  
 *  (at your option) any later version.  
 *  
 *  This program is distributed in the hope that it will be useful,  
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of  
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the  
 *  GNU General Public License for more details.  
 *  
 *  You should have received a copy of the GNU General Public License along  
 *  with this program; if not, write to the Free Software Foundation, Inc.,  
 *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.  
 *    
 *  Contact:  
 *    
 *  Paul Willmott  
 *  vp9mu@amsat.org  
 */  
  
